@@ -87,10 +87,9 @@ static FREERDP_ADDIN** freerdp_channels_list_client_static_addins(LPCSTR pszName
                                                                   LPCSTR pszSubsystem,
                                                                   LPCSTR pszType, DWORD dwFlags)
 {
-	size_t i, j;
-	DWORD nAddins;
+	DWORD nAddins = 0;
 	FREERDP_ADDIN** ppAddins = NULL;
-	const STATIC_SUBSYSTEM_ENTRY* subsystems;
+	const STATIC_SUBSYSTEM_ENTRY* subsystems = NULL;
 	nAddins = 0;
 	ppAddins = (FREERDP_ADDIN**)calloc(128, sizeof(FREERDP_ADDIN*));
 
@@ -102,7 +101,7 @@ static FREERDP_ADDIN** freerdp_channels_list_client_static_addins(LPCSTR pszName
 
 	ppAddins[nAddins] = NULL;
 
-	for (i = 0; CLIENT_STATIC_ADDIN_TABLE[i].name != NULL; i++)
+	for (size_t i = 0; CLIENT_STATIC_ADDIN_TABLE[i].name != NULL; i++)
 	{
 		FREERDP_ADDIN* pAddin = (FREERDP_ADDIN*)calloc(1, sizeof(FREERDP_ADDIN));
 
@@ -119,7 +118,7 @@ static FREERDP_ADDIN** freerdp_channels_list_client_static_addins(LPCSTR pszName
 		ppAddins[nAddins++] = pAddin;
 		subsystems = (const STATIC_SUBSYSTEM_ENTRY*)CLIENT_STATIC_ADDIN_TABLE[i].table;
 
-		for (j = 0; subsystems[j].name != NULL; j++)
+		for (size_t j = 0; subsystems[j].name != NULL; j++)
 		{
 			pAddin = (FREERDP_ADDIN*)calloc(1, sizeof(FREERDP_ADDIN));
 
@@ -164,20 +163,19 @@ static HANDLE FindFirstFileUTF8(LPCSTR pszSearchPath, WIN32_FIND_DATAW* FindData
 static FREERDP_ADDIN** freerdp_channels_list_dynamic_addins(LPCSTR pszName, LPCSTR pszSubsystem,
                                                             LPCSTR pszType, DWORD dwFlags)
 {
-	int index;
-	int nDashes;
-	HANDLE hFind;
-	DWORD nAddins;
-	LPSTR pszPattern;
-	size_t cchPattern;
+	int nDashes = 0;
+	HANDLE hFind = NULL;
+	DWORD nAddins = 0;
+	LPSTR pszPattern = NULL;
+	size_t cchPattern = 0;
 	LPCSTR pszAddinPath = FREERDP_ADDIN_PATH;
 	LPCSTR pszInstallPrefix = FREERDP_INSTALL_PREFIX;
-	LPCSTR pszExtension;
-	LPSTR pszSearchPath;
-	size_t cchSearchPath;
-	size_t cchAddinPath;
-	size_t cchInstallPrefix;
-	FREERDP_ADDIN** ppAddins;
+	LPCSTR pszExtension = NULL;
+	LPSTR pszSearchPath = NULL;
+	size_t cchSearchPath = 0;
+	size_t cchAddinPath = 0;
+	size_t cchInstallPrefix = 0;
+	FREERDP_ADDIN** ppAddins = NULL;
 	WIN32_FIND_DATAW FindData = { 0 };
 	cchAddinPath = strnlen(pszAddinPath, sizeof(FREERDP_ADDIN_PATH));
 	cchInstallPrefix = strnlen(pszInstallPrefix, sizeof(FREERDP_INSTALL_PREFIX));
@@ -269,12 +267,12 @@ static FREERDP_ADDIN** freerdp_channels_list_dynamic_addins(LPCSTR pszName, LPCS
 			goto skip;
 
 		nDashes = 0;
-		for (index = 0; cFileName[index]; index++)
+		for (size_t index = 0; cFileName[index]; index++)
 			nDashes += (cFileName[index] == '-') ? 1 : 0;
 
 		if (nDashes == 1)
 		{
-			size_t len;
+			size_t len = 0;
 			char* p[2] = { 0 };
 			/* <name>-client.<extension> */
 			p[0] = cFileName;
@@ -300,7 +298,7 @@ static FREERDP_ADDIN** freerdp_channels_list_dynamic_addins(LPCSTR pszName, LPCS
 		}
 		else if (nDashes == 2)
 		{
-			size_t len;
+			size_t len = 0;
 			char* p[4] = { 0 };
 			/* <name>-client-<subsystem>.<extension> */
 			p[0] = cFileName;
@@ -343,7 +341,7 @@ static FREERDP_ADDIN** freerdp_channels_list_dynamic_addins(LPCSTR pszName, LPCS
 		}
 		else if (nDashes == 3)
 		{
-			size_t len;
+			size_t len = 0;
 			char* p[5] = { 0 };
 			/* <name>-client-<subsystem>-<type>.<extension> */
 			p[0] = cFileName;
@@ -427,12 +425,10 @@ FREERDP_ADDIN** freerdp_channels_list_addins(LPCSTR pszName, LPCSTR pszSubsystem
 
 void freerdp_channels_addin_list_free(FREERDP_ADDIN** ppAddins)
 {
-	size_t index;
-
 	if (!ppAddins)
 		return;
 
-	for (index = 0; ppAddins[index] != NULL; index++)
+	for (size_t index = 0; ppAddins[index] != NULL; index++)
 		free(ppAddins[index]);
 
 	free(ppAddins);
@@ -442,9 +438,7 @@ extern const STATIC_ENTRY CLIENT_VirtualChannelEntryEx_TABLE[];
 
 static BOOL freerdp_channels_is_virtual_channel_entry_ex(LPCSTR pszName)
 {
-	size_t i;
-
-	for (i = 0; CLIENT_VirtualChannelEntryEx_TABLE[i].name != NULL; i++)
+	for (size_t i = 0; CLIENT_VirtualChannelEntryEx_TABLE[i].name != NULL; i++)
 	{
 		const STATIC_ENTRY* entry = &CLIENT_VirtualChannelEntryEx_TABLE[i];
 
@@ -595,6 +589,19 @@ static void free_msg(void* obj)
 	}
 }
 
+static void channel_client_handler_free(msg_proc_internals* internals)
+{
+	if (!internals)
+		return;
+
+	if (internals->thread)
+		CloseHandle(internals->thread);
+	MessageQueue_Free(internals->queue);
+	Stream_Free(internals->data_in, TRUE);
+	free(internals->channel_name);
+	free(internals);
+}
+
 /*  Create message queue and thread or not, depending on settings */
 void* channel_client_create_handler(rdpContext* ctx, LPVOID userdata, MsgHandler msg_handler,
                                     const char* channel_name)
@@ -603,11 +610,16 @@ void* channel_client_create_handler(rdpContext* ctx, LPVOID userdata, MsgHandler
 	if (!internals)
 	{
 		WLog_ERR(TAG, "calloc failed!");
-		return 0;
+		return NULL;
 	}
 	internals->msg_handler = msg_handler;
 	internals->userdata = userdata;
-	internals->channel_name = _strdup(channel_name);
+	if (channel_name)
+	{
+		internals->channel_name = _strdup(channel_name);
+		if (!internals->channel_name)
+			goto fail;
+	}
 	WINPR_ASSERT(ctx);
 	WINPR_ASSERT(ctx->settings);
 	internals->ctx = ctx;
@@ -620,25 +632,28 @@ void* channel_client_create_handler(rdpContext* ctx, LPVOID userdata, MsgHandler
 		if (!internals->queue)
 		{
 			WLog_ERR(TAG, "MessageQueue_New failed!");
-			return 0;
+			goto fail;
 		}
 
 		if (!(internals->thread =
 		          CreateThread(NULL, 0, channel_client_thread_proc, (void*)internals, 0, NULL)))
 		{
 			WLog_ERR(TAG, "CreateThread failed!");
-			MessageQueue_Free(internals->queue);
-			internals->queue = NULL;
+			goto fail;
 		}
 	}
 	return internals;
+
+fail:
+	channel_client_handler_free(internals);
+	return NULL;
 }
 /* post a message in the queue or directly call the processing handler */
 UINT channel_client_post_message(void* MsgsHandle, LPVOID pData, UINT32 dataLength,
                                  UINT32 totalLength, UINT32 dataFlags)
 {
 	msg_proc_internals* internals = MsgsHandle;
-	wStream* data_in;
+	wStream* data_in = NULL;
 
 	if (!internals)
 	{
@@ -654,9 +669,12 @@ UINT channel_client_post_message(void* MsgsHandle, LPVOID pData, UINT32 dataLeng
 	if (dataFlags & CHANNEL_FLAG_FIRST)
 	{
 		if (internals->data_in)
-			Stream_Free(internals->data_in, TRUE);
-
-		internals->data_in = Stream_New(NULL, totalLength);
+		{
+			if (!Stream_EnsureCapacity(internals->data_in, totalLength))
+				return CHANNEL_RC_NO_MEMORY;
+		}
+		else
+			internals->data_in = Stream_New(NULL, totalLength);
 	}
 
 	if (!(data_in = internals->data_in))
@@ -713,7 +731,7 @@ UINT channel_client_post_message(void* MsgsHandle, LPVOID pData, UINT32 dataLeng
 UINT channel_client_quit_handler(void* MsgsHandle)
 {
 	msg_proc_internals* internals = MsgsHandle;
-	UINT rc;
+	UINT rc = 0;
 	if (!internals)
 	{
 		/* TODO: return some error here */
@@ -736,12 +754,8 @@ UINT channel_client_quit_handler(void* MsgsHandle)
 				return rc;
 			}
 		}
-		MessageQueue_Free(internals->queue);
-		CloseHandle(internals->thread);
 	}
 
-	Stream_Free(internals->data_in, TRUE);
-	free(internals->channel_name);
-	free(internals);
+	channel_client_handler_free(internals);
 	return CHANNEL_RC_OK;
 }
