@@ -41,7 +41,7 @@ static BOOL rail_is_feature_supported(const rdpContext* context, UINT32 featureM
 UINT rail_send_pdu(railPlugin* rail, wStream* s, UINT16 orderType)
 {
 	char buffer[128] = { 0 };
-	UINT16 orderLength;
+	UINT16 orderLength = 0;
 
 	if (!rail || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -110,7 +110,7 @@ static UINT rail_read_server_minmaxinfo_order(wStream* s, RAIL_MINMAXINFO_ORDER*
 static UINT rail_read_server_localmovesize_order(wStream* s,
                                                  RAIL_LOCALMOVESIZE_ORDER* localMoveSize)
 {
-	UINT16 isMoveSizeStart;
+	UINT16 isMoveSizeStart = 0;
 
 	if (!s || !localMoveSize)
 		return ERROR_INVALID_PARAMETER;
@@ -184,7 +184,7 @@ static UINT rail_write_client_exec_order(wStream* s, UINT16 flags,
                                          const RAIL_UNICODE_STRING* workingDir,
                                          const RAIL_UNICODE_STRING* arguments)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!s || !exeOrFile || !workingDir || !arguments)
 		return ERROR_INVALID_PARAMETER;
@@ -228,7 +228,7 @@ static UINT rail_write_client_exec_order(wStream* s, UINT16 flags,
 
 static UINT rail_write_client_activate_order(wStream* s, const RAIL_ACTIVATE_ORDER* activate)
 {
-	BYTE enabled;
+	BYTE enabled = 0;
 
 	if (!s || !activate)
 		return ERROR_INVALID_PARAMETER;
@@ -341,7 +341,7 @@ static UINT rail_recv_handshake_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_HANDSHAKE_ORDER serverHandshake = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -392,7 +392,7 @@ static UINT rail_recv_compartmentinfo_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_COMPARTMENT_INFO_ORDER pdu = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -416,7 +416,8 @@ static UINT rail_recv_compartmentinfo_order(railPlugin* rail, wStream* s)
 
 BOOL rail_is_feature_supported(const rdpContext* context, UINT32 featureMask)
 {
-	UINT32 supported, masked;
+	UINT32 supported = 0;
+	UINT32 masked = 0;
 
 	if (!context || !context->settings)
 		return FALSE;
@@ -451,7 +452,7 @@ static UINT rail_recv_handshake_ex_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_HANDSHAKE_EX_ORDER serverHandshake = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!rail || !context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -500,7 +501,7 @@ static UINT rail_recv_exec_result_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_EXEC_RESULT_ORDER execResult = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -533,8 +534,8 @@ static UINT rail_recv_server_sysparam_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_SYSPARAM_ORDER sysparam;
-	UINT error;
-	BOOL extendedSpiSupported;
+	UINT error = 0;
+	BOOL extendedSpiSupported = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -566,7 +567,7 @@ static UINT rail_recv_server_minmaxinfo_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_MINMAXINFO_ORDER minMaxInfo = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -597,7 +598,7 @@ static UINT rail_recv_server_localmovesize_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_LOCALMOVESIZE_ORDER localMoveSize = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -628,7 +629,7 @@ static UINT rail_recv_server_get_appid_resp_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_GET_APPID_RESP_ORDER getAppIdResp = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -660,7 +661,7 @@ static UINT rail_recv_langbar_info_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_LANGBAR_INFO_ORDER langBarInfo = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -703,7 +704,7 @@ static UINT rail_recv_taskbar_info_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_TASKBAR_INFO_ORDER taskBarInfo = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -746,7 +747,7 @@ static UINT rail_recv_zorder_sync_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_ZORDER_SYNC zorder = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -773,7 +774,7 @@ static UINT rail_recv_zorder_sync_order(railPlugin* rail, wStream* s)
 
 static UINT rail_read_cloak_order(wStream* s, RAIL_CLOAK* cloak)
 {
-	BYTE cloaked;
+	BYTE cloaked = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, RAIL_CLOAK_ORDER_LENGTH))
 		return ERROR_INVALID_DATA;
@@ -788,7 +789,7 @@ static UINT rail_recv_cloak_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_CLOAK cloak = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -817,7 +818,7 @@ static UINT rail_recv_cloak_order(railPlugin* rail, wStream* s)
 
 static UINT rail_read_power_display_request_order(wStream* s, RAIL_POWER_DISPLAY_REQUEST* power)
 {
-	UINT32 active;
+	UINT32 active = 0;
 
 	if (!s || !power)
 		return ERROR_INVALID_PARAMETER;
@@ -834,7 +835,7 @@ static UINT rail_recv_power_display_request_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_POWER_DISPLAY_REQUEST power = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -897,7 +898,7 @@ static UINT rail_recv_get_application_id_extended_response_order(railPlugin* rai
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	RAIL_GET_APPID_RESP_EX id = { 0 };
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -938,7 +939,7 @@ static UINT rail_recv_textscaleinfo_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	UINT32 TextScaleFactor = 0;
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -972,7 +973,7 @@ static UINT rail_recv_caretblinkinfo_order(railPlugin* rail, wStream* s)
 {
 	RailClientContext* context = rail_get_client_interface(rail);
 	UINT32 CaretBlinkRate = 0;
-	UINT error;
+	UINT error = 0;
 
 	if (!context)
 		return ERROR_INVALID_PARAMETER;
@@ -999,8 +1000,8 @@ UINT rail_order_recv(LPVOID userdata, wStream* s)
 {
 	char buffer[128] = { 0 };
 	railPlugin* rail = userdata;
-	UINT16 orderType;
-	UINT16 orderLength;
+	UINT16 orderType = 0;
+	UINT16 orderLength = 0;
 	UINT error = CHANNEL_RC_OK;
 
 	if (!rail || !s)
@@ -1106,8 +1107,8 @@ UINT rail_order_recv(LPVOID userdata, wStream* s)
  */
 UINT rail_send_handshake_order(railPlugin* rail, const RAIL_HANDSHAKE_ORDER* handshake)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !handshake)
 		return ERROR_INVALID_PARAMETER;
@@ -1133,8 +1134,8 @@ UINT rail_send_handshake_order(railPlugin* rail, const RAIL_HANDSHAKE_ORDER* han
  */
 UINT rail_send_handshake_ex_order(railPlugin* rail, const RAIL_HANDSHAKE_EX_ORDER* handshakeEx)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !handshakeEx)
 		return ERROR_INVALID_PARAMETER;
@@ -1160,8 +1161,8 @@ UINT rail_send_handshake_ex_order(railPlugin* rail, const RAIL_HANDSHAKE_EX_ORDE
  */
 UINT rail_send_client_status_order(railPlugin* rail, const RAIL_CLIENT_STATUS_ORDER* clientStatus)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !clientStatus)
 		return ERROR_INVALID_PARAMETER;
@@ -1194,9 +1195,9 @@ UINT rail_send_client_exec_order(railPlugin* rail, UINT16 flags,
                                  const RAIL_UNICODE_STRING* workingDir,
                                  const RAIL_UNICODE_STRING* arguments)
 {
-	wStream* s;
-	UINT error;
-	size_t length;
+	wStream* s = NULL;
+	UINT error = 0;
+	size_t length = 0;
 
 	if (!rail || !exeOrFile || !workingDir || !arguments)
 		return ERROR_INVALID_PARAMETER;
@@ -1234,8 +1235,8 @@ out:
  */
 UINT rail_send_client_activate_order(railPlugin* rail, const RAIL_ACTIVATE_ORDER* activate)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !activate)
 		return ERROR_INVALID_PARAMETER;
@@ -1264,8 +1265,8 @@ UINT rail_send_client_activate_order(railPlugin* rail, const RAIL_ACTIVATE_ORDER
  */
 UINT rail_send_client_sysmenu_order(railPlugin* rail, const RAIL_SYSMENU_ORDER* sysmenu)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !sysmenu)
 		return ERROR_INVALID_PARAMETER;
@@ -1294,8 +1295,8 @@ UINT rail_send_client_sysmenu_order(railPlugin* rail, const RAIL_SYSMENU_ORDER*
  */
 UINT rail_send_client_syscommand_order(railPlugin* rail, const RAIL_SYSCOMMAND_ORDER* syscommand)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !syscommand)
 		return ERROR_INVALID_PARAMETER;
@@ -1325,8 +1326,8 @@ UINT rail_send_client_syscommand_order(railPlugin* rail, const RAIL_SYSCOMMAND_O
 UINT rail_send_client_notify_event_order(railPlugin* rail,
                                          const RAIL_NOTIFY_EVENT_ORDER* notifyEvent)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !notifyEvent)
 		return ERROR_INVALID_PARAMETER;
@@ -1355,8 +1356,8 @@ UINT rail_send_client_notify_event_order(railPlugin* rail,
  */
 UINT rail_send_client_window_move_order(railPlugin* rail, const RAIL_WINDOW_MOVE_ORDER* windowMove)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !windowMove)
 		return ERROR_INVALID_PARAMETER;
@@ -1386,8 +1387,8 @@ UINT rail_send_client_window_move_order(railPlugin* rail, const RAIL_WINDOW_MOVE
 UINT rail_send_client_get_appid_req_order(railPlugin* rail,
                                           const RAIL_GET_APPID_REQ_ORDER* getAppIdReq)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !getAppIdReq)
 		return ERROR_INVALID_PARAMETER;
@@ -1417,8 +1418,8 @@ UINT rail_send_client_get_appid_req_order(railPlugin* rail,
 UINT rail_send_client_langbar_info_order(railPlugin* rail,
                                          const RAIL_LANGBAR_INFO_ORDER* langBarInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !langBarInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -1446,8 +1447,8 @@ UINT rail_send_client_langbar_info_order(railPlugin* rail,
 UINT rail_send_client_languageime_info_order(railPlugin* rail,
                                              const RAIL_LANGUAGEIME_INFO_ORDER* langImeInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !langImeInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -1475,8 +1476,8 @@ UINT rail_send_client_languageime_info_order(railPlugin* rail,
 UINT rail_send_client_compartment_info_order(railPlugin* rail,
                                              const RAIL_COMPARTMENT_INFO_ORDER* compartmentInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !compartmentInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -1503,8 +1504,8 @@ UINT rail_send_client_compartment_info_order(railPlugin* rail,
 
 UINT rail_send_client_cloak_order(railPlugin* rail, const RAIL_CLOAK* cloak)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail || !cloak)
 		return ERROR_INVALID_PARAMETER;
@@ -1526,8 +1527,8 @@ UINT rail_send_client_cloak_order(railPlugin* rail, const RAIL_CLOAK* cloak)
 
 UINT rail_send_client_snap_arrange_order(railPlugin* rail, const RAIL_SNAP_ARRANGE* snap)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!rail)
 		return ERROR_INVALID_PARAMETER;
