@@ -84,11 +84,11 @@ static void request_free(void* value);
 
 static struct libusb_transfer* list_contains(wArrayList* list, UINT32 streamID)
 {
-	size_t x, count;
+	size_t count = 0;
 	if (!list)
 		return NULL;
 	count = ArrayList_Count(list);
-	for (x = 0; x < count; x++)
+	for (size_t x = 0; x < count; x++)
 	{
 		struct libusb_transfer* transfer = ArrayList_GetItem(list, x);
 
@@ -205,7 +205,7 @@ static ASYNC_TRANSFER_USER_DATA* async_transfer_user_data_new(IUDEVICE* idev, UI
                                                               BOOL NoAck, t_isoch_transfer_cb cb,
                                                               GENERIC_CHANNEL_CALLBACK* callback)
 {
-	ASYNC_TRANSFER_USER_DATA* user_data;
+	ASYNC_TRANSFER_USER_DATA* user_data = NULL;
 	UDEVICE* pdev = (UDEVICE*)idev;
 
 	if (BufferSize > UINT32_MAX)
@@ -260,13 +260,12 @@ static void LIBUSB_CALL func_iso_callback(struct libusb_transfer* transfer)
 	{
 		case LIBUSB_TRANSFER_COMPLETED:
 		{
-			int i;
 			UINT32 index = 0;
 			BYTE* dataStart = Stream_Pointer(user_data->data);
 			Stream_SetPosition(user_data->data,
 			                   40); /* TS_URB_ISOCH_TRANSFER_RESULT IsoPacket offset */
 
-			for (i = 0; i < transfer->num_iso_packets; i++)
+			for (int i = 0; i < transfer->num_iso_packets; i++)
 			{
 				const UINT32 act_len = transfer->iso_packet_desc[i].actual_length;
 				Stream_Write_UINT32(user_data->data, index);
@@ -327,20 +326,15 @@ static const LIBUSB_ENDPOINT_DESCEIPTOR* func_get_ep_desc(LIBUSB_CONFIG_DESCRIPT
                                                           MSUSB_CONFIG_DESCRIPTOR* MsConfig,
                                                           UINT32 EndpointAddress)
 {
-	BYTE alt;
-	UINT32 inum, pnum;
-	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces;
-	const LIBUSB_INTERFACE* interface;
-	const LIBUSB_ENDPOINT_DESCEIPTOR* endpoint;
-	MsInterfaces = MsConfig->MsInterfaces;
-	interface = LibusbConfig->interface;
+	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces = MsConfig->MsInterfaces;
+	const LIBUSB_INTERFACE* interface = LibusbConfig->interface;
 
-	for (inum = 0; inum < MsConfig->NumInterfaces; inum++)
+	for (UINT32 inum = 0; inum < MsConfig->NumInterfaces; inum++)
 	{
-		alt = MsInterfaces[inum]->AlternateSetting;
-		endpoint = interface[inum].altsetting[alt].endpoint;
+		BYTE alt = MsInterfaces[inum]->AlternateSetting;
+		const LIBUSB_ENDPOINT_DESCEIPTOR* endpoint = interface[inum].altsetting[alt].endpoint;
 
-		for (pnum = 0; pnum < MsInterfaces[inum]->NumberOfPipes; pnum++)
+		for (UINT32 pnum = 0; pnum < MsInterfaces[inum]->NumberOfPipes; pnum++)
 		{
 			if (endpoint[pnum].bEndpointAddress == EndpointAddress)
 			{
@@ -354,9 +348,9 @@ static const LIBUSB_ENDPOINT_DESCEIPTOR* func_get_ep_desc(LIBUSB_CONFIG_DESCRIPT
 
 static void LIBUSB_CALL func_bulk_transfer_cb(struct libusb_transfer* transfer)
 {
-	ASYNC_TRANSFER_USER_DATA* user_data;
-	uint32_t streamID;
-	wArrayList* list;
+	ASYNC_TRANSFER_USER_DATA* user_data = NULL;
+	uint32_t streamID = 0;
+	wArrayList* list = NULL;
 
 	user_data = (ASYNC_TRANSFER_USER_DATA*)transfer->user_data;
 	if (!user_data)
@@ -467,9 +461,7 @@ static int func_config_release_all_interface(URBDRC_PLUGIN* urbdrc,
                                              LIBUSB_DEVICE_HANDLE* libusb_handle,
                                              UINT32 NumInterfaces)
 {
-	UINT32 i;
-
-	for (i = 0; i < NumInterfaces; i++)
+	for (UINT32 i = 0; i < NumInterfaces; i++)
 	{
 		int ret = libusb_release_interface(libusb_handle, i);
 
@@ -483,9 +475,9 @@ static int func_config_release_all_interface(URBDRC_PLUGIN* urbdrc,
 static int func_claim_all_interface(URBDRC_PLUGIN* urbdrc, LIBUSB_DEVICE_HANDLE* libusb_handle,
                                     int NumInterfaces)
 {
-	int i, ret;
+	int ret = 0;
 
-	for (i = 0; i < NumInterfaces; i++)
+	for (int i = 0; i < NumInterfaces; i++)
 	{
 		ret = libusb_claim_interface(libusb_handle, i);
 
@@ -499,12 +491,11 @@ static int func_claim_all_interface(URBDRC_PLUGIN* urbdrc, LIBUSB_DEVICE_HANDLE*
 static LIBUSB_DEVICE* udev_get_libusb_dev(libusb_context* context, uint8_t bus_number,
                                           uint8_t dev_number)
 {
-	ssize_t i;
 	LIBUSB_DEVICE** libusb_list = NULL;
 	LIBUSB_DEVICE* device = NULL;
 	const ssize_t total_device = libusb_get_device_list(context, &libusb_list);
 
-	for (i = 0; i < total_device; i++)
+	for (ssize_t i = 0; i < total_device; i++)
 	{
 		LIBUSB_DEVICE* dev = libusb_list[i];
 		if ((bus_number == libusb_get_bus_number(dev)) &&
@@ -520,7 +511,7 @@ static LIBUSB_DEVICE* udev_get_libusb_dev(libusb_context* context, uint8_t bus_n
 
 static LIBUSB_DEVICE_DESCRIPTOR* udev_new_descript(URBDRC_PLUGIN* urbdrc, LIBUSB_DEVICE* libusb_dev)
 {
-	int ret;
+	int ret = 0;
 	LIBUSB_DEVICE_DESCRIPTOR* descriptor =
 	    (LIBUSB_DEVICE_DESCRIPTOR*)calloc(1, sizeof(LIBUSB_DEVICE_DESCRIPTOR));
 	if (!descriptor)
@@ -538,11 +529,12 @@ static LIBUSB_DEVICE_DESCRIPTOR* udev_new_descript(URBDRC_PLUGIN* urbdrc, LIBUSB
 
 static int libusb_udev_select_interface(IUDEVICE* idev, BYTE InterfaceNumber, BYTE AlternateSetting)
 {
-	int error = 0, diff = 0;
+	int error = 0;
+	int diff = 0;
 	UDEVICE* pdev = (UDEVICE*)idev;
-	URBDRC_PLUGIN* urbdrc;
-	MSUSB_CONFIG_DESCRIPTOR* MsConfig;
-	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	MSUSB_CONFIG_DESCRIPTOR* MsConfig = NULL;
+	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces = NULL;
 
 	if (!pdev || !pdev->urbdrc)
 		return -1;
@@ -583,19 +575,19 @@ static MSUSB_CONFIG_DESCRIPTOR*
 libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsConfig)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces;
-	MSUSB_INTERFACE_DESCRIPTOR* MsInterface;
-	MSUSB_PIPE_DESCRIPTOR** MsPipes;
-	MSUSB_PIPE_DESCRIPTOR* MsPipe;
-	MSUSB_PIPE_DESCRIPTOR** t_MsPipes;
-	MSUSB_PIPE_DESCRIPTOR* t_MsPipe;
-	LIBUSB_CONFIG_DESCRIPTOR* LibusbConfig;
-	const LIBUSB_INTERFACE* LibusbInterface;
-	const LIBUSB_INTERFACE_DESCRIPTOR* LibusbAltsetting;
-	const LIBUSB_ENDPOINT_DESCEIPTOR* LibusbEndpoint;
-	BYTE LibusbNumEndpoint;
-	URBDRC_PLUGIN* urbdrc;
-	UINT32 inum = 0, pnum = 0, MsOutSize = 0;
+	MSUSB_INTERFACE_DESCRIPTOR** MsInterfaces = NULL;
+	MSUSB_INTERFACE_DESCRIPTOR* MsInterface = NULL;
+	MSUSB_PIPE_DESCRIPTOR** MsPipes = NULL;
+	MSUSB_PIPE_DESCRIPTOR* MsPipe = NULL;
+	MSUSB_PIPE_DESCRIPTOR** t_MsPipes = NULL;
+	MSUSB_PIPE_DESCRIPTOR* t_MsPipe = NULL;
+	LIBUSB_CONFIG_DESCRIPTOR* LibusbConfig = NULL;
+	const LIBUSB_INTERFACE* LibusbInterface = NULL;
+	const LIBUSB_INTERFACE_DESCRIPTOR* LibusbAltsetting = NULL;
+	const LIBUSB_ENDPOINT_DESCEIPTOR* LibusbEndpoint = NULL;
+	BYTE LibusbNumEndpoint = 0;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	UINT32 MsOutSize = 0;
 
 	if (!pdev || !pdev->LibusbConfig || !pdev->urbdrc || !MsConfig)
 		return NULL;
@@ -614,7 +606,7 @@ libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsC
 	/* replace MsPipes for libusb */
 	MsInterfaces = MsConfig->MsInterfaces;
 
-	for (inum = 0; inum < MsConfig->NumInterfaces; inum++)
+	for (UINT32 inum = 0; inum < MsConfig->NumInterfaces; inum++)
 	{
 		MsInterface = MsInterfaces[inum];
 		/* get libusb's number of endpoints */
@@ -624,7 +616,7 @@ libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsC
 		t_MsPipes =
 		    (MSUSB_PIPE_DESCRIPTOR**)calloc(LibusbNumEndpoint, sizeof(MSUSB_PIPE_DESCRIPTOR*));
 
-		for (pnum = 0; pnum < LibusbNumEndpoint; pnum++)
+		for (UINT32 pnum = 0; pnum < LibusbNumEndpoint; pnum++)
 		{
 			t_MsPipe = (MSUSB_PIPE_DESCRIPTOR*)calloc(1, sizeof(MSUSB_PIPE_DESCRIPTOR));
 
@@ -665,7 +657,7 @@ libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsC
 	    MsConfig->bConfigurationValue | (pdev->bus_number << 24) | (pdev->dev_number << 16);
 	MsInterfaces = MsConfig->MsInterfaces;
 
-	for (inum = 0; inum < MsConfig->NumInterfaces; inum++)
+	for (UINT32 inum = 0; inum < MsConfig->NumInterfaces; inum++)
 	{
 		MsOutSize += 16;
 		MsInterface = MsInterfaces[inum];
@@ -689,7 +681,7 @@ libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsC
 		MsPipes = MsInterface->MsPipes;
 		LibusbNumEndpoint = LibusbAltsetting->bNumEndpoints;
 
-		for (pnum = 0; pnum < LibusbNumEndpoint; pnum++)
+		for (UINT32 pnum = 0; pnum < LibusbNumEndpoint; pnum++)
 		{
 			MsOutSize += 20;
 			MsPipe = MsPipes[pnum];
@@ -736,11 +728,11 @@ libusb_udev_complete_msconfig_setup(IUDEVICE* idev, MSUSB_CONFIG_DESCRIPTOR* MsC
 static int libusb_udev_select_configuration(IUDEVICE* idev, UINT32 bConfigurationValue)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	MSUSB_CONFIG_DESCRIPTOR* MsConfig;
-	LIBUSB_DEVICE_HANDLE* libusb_handle;
-	LIBUSB_DEVICE* libusb_dev;
-	URBDRC_PLUGIN* urbdrc;
-	LIBUSB_CONFIG_DESCRIPTOR** LibusbConfig;
+	MSUSB_CONFIG_DESCRIPTOR* MsConfig = NULL;
+	LIBUSB_DEVICE_HANDLE* libusb_handle = NULL;
+	LIBUSB_DEVICE* libusb_dev = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	LIBUSB_CONFIG_DESCRIPTOR** LibusbConfig = NULL;
 	int ret = 0;
 
 	if (!pdev || !pdev->MsConfig || !pdev->LibusbConfig || !pdev->urbdrc)
@@ -825,16 +817,17 @@ static UINT32 libusb_udev_control_query_device_text(IUDEVICE* idev, UINT32 TextT
                                                     BYTE* Buffer)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	LIBUSB_DEVICE_DESCRIPTOR* devDescriptor;
+	LIBUSB_DEVICE_DESCRIPTOR* devDescriptor = NULL;
 	const char strDesc[] = "Generic Usb String";
 	char deviceLocation[25] = { 0 };
-	BYTE bus_number;
-	BYTE device_address;
+	BYTE bus_number = 0;
+	BYTE device_address = 0;
 	int ret = 0;
-	size_t i, len;
-	URBDRC_PLUGIN* urbdrc;
+	size_t len = 0;
+	URBDRC_PLUGIN* urbdrc = NULL;
 	WCHAR* text = (WCHAR*)Buffer;
-	BYTE slen, locale;
+	BYTE slen = 0;
+	BYTE locale = 0;
 	const UINT8 inSize = *BufferSize;
 
 	*BufferSize = 0;
@@ -871,7 +864,7 @@ static UINT32 libusb_udev_control_query_device_text(IUDEVICE* idev, UINT32 TextT
 				           msg, ret, devDescriptor->iProduct);
 
 				len = MIN(sizeof(strDesc), inSize);
-				for (i = 0; i < len; i++)
+				for (ssize_t i = 0; i < len; i++)
 					text[i] = (WCHAR)strDesc[i];
 
 				*BufferSize = (BYTE)(len * 2);
@@ -906,7 +899,7 @@ static UINT32 libusb_udev_control_query_device_text(IUDEVICE* idev, UINT32 TextT
 
 			len = strnlen(deviceLocation,
 			              MIN(sizeof(deviceLocation), (inSize > 0) ? inSize - 1U : 0));
-			for (i = 0; i < len; i++)
+			for (ssize_t i = 0; i < len; i++)
 				text[i] = (WCHAR)deviceLocation[i];
 			text[len++] = '\0';
 			*BufferSize = (UINT8)(len * sizeof(WCHAR));
@@ -1022,9 +1015,9 @@ static int libusb_udev_query_device_descriptor(IUDEVICE* idev, int offset)
 
 static BOOL libusb_udev_detach_kernel_driver(IUDEVICE* idev)
 {
-	int i, err = 0;
+	int err = 0;
 	UDEVICE* pdev = (UDEVICE*)idev;
-	URBDRC_PLUGIN* urbdrc;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!pdev || !pdev->LibusbConfig || !pdev->libusb_handle || !pdev->urbdrc)
 		return FALSE;
@@ -1036,7 +1029,7 @@ static BOOL libusb_udev_detach_kernel_driver(IUDEVICE* idev)
 
 	if ((pdev->status & URBDRC_DEVICE_DETACH_KERNEL) == 0)
 	{
-		for (i = 0; i < pdev->LibusbConfig->bNumInterfaces; i++)
+		for (int i = 0; i < pdev->LibusbConfig->bNumInterfaces; i++)
 		{
 			err = libusb_kernel_driver_active(pdev->libusb_handle, i);
 			log_libusb_result(urbdrc->log, WLOG_DEBUG, "libusb_kernel_driver_active", err);
@@ -1057,13 +1050,13 @@ static BOOL libusb_udev_detach_kernel_driver(IUDEVICE* idev)
 
 static BOOL libusb_udev_attach_kernel_driver(IUDEVICE* idev)
 {
-	int i, err = 0;
+	int err = 0;
 	UDEVICE* pdev = (UDEVICE*)idev;
 
 	if (!pdev || !pdev->LibusbConfig || !pdev->libusb_handle || !pdev->urbdrc)
 		return FALSE;
 
-	for (i = 0; i < pdev->LibusbConfig->bNumInterfaces && err != LIBUSB_ERROR_NO_DEVICE; i++)
+	for (int i = 0; i < pdev->LibusbConfig->bNumInterfaces && err != LIBUSB_ERROR_NO_DEVICE; i++)
 	{
 		err = libusb_release_interface(pdev->libusb_handle, i);
 
@@ -1097,7 +1090,7 @@ static int libusb_udev_is_exist(IUDEVICE* idev)
 static int libusb_udev_is_channel_closed(IUDEVICE* idev)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	IUDEVMAN* udevman;
+	IUDEVMAN* udevman = NULL;
 	if (!pdev || !pdev->urbdrc)
 		return 1;
 
@@ -1177,8 +1170,9 @@ static int libusb_udev_query_device_port_status(IUDEVICE* idev, UINT32* UsbdStat
                                                 UINT32* BufferSize, BYTE* Buffer)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	int success = 0, ret;
-	URBDRC_PLUGIN* urbdrc;
+	int success = 0;
+	int ret = 0;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!pdev || !pdev->urbdrc)
 		return -1;
@@ -1213,12 +1207,12 @@ static int libusb_udev_isoch_transfer(IUDEVICE* idev, GENERIC_CHANNEL_CALLBACK*
                                       UINT32 NumberOfPackets, UINT32 BufferSize, const BYTE* Buffer,
                                       t_isoch_transfer_cb cb, UINT32 Timeout)
 {
-	int rc;
+	int rc = 0;
 	UINT32 iso_packet_size = 0;
 	UDEVICE* pdev = (UDEVICE*)idev;
-	ASYNC_TRANSFER_USER_DATA* user_data;
+	ASYNC_TRANSFER_USER_DATA* user_data = NULL;
 	struct libusb_transfer* iso_transfer = NULL;
-	URBDRC_PLUGIN* urbdrc;
+	URBDRC_PLUGIN* urbdrc = NULL;
 	size_t outSize = (NumberOfPackets * 12);
 	uint32_t streamID = 0x40000000 | RequestId;
 
@@ -1310,13 +1304,13 @@ static int libusb_udev_bulk_or_interrupt_transfer(IUDEVICE* idev,
                                                   BOOL NoAck, UINT32 BufferSize, const BYTE* data,
                                                   t_isoch_transfer_cb cb, UINT32 Timeout)
 {
-	int rc;
-	UINT32 transfer_type;
+	int rc = 0;
+	UINT32 transfer_type = 0;
 	UDEVICE* pdev = (UDEVICE*)idev;
-	const LIBUSB_ENDPOINT_DESCEIPTOR* ep_desc;
+	const LIBUSB_ENDPOINT_DESCEIPTOR* ep_desc = NULL;
 	struct libusb_transfer* transfer = NULL;
-	URBDRC_PLUGIN* urbdrc;
-	ASYNC_TRANSFER_USER_DATA* user_data;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	ASYNC_TRANSFER_USER_DATA* user_data = NULL;
 	uint32_t streamID = 0x80000000 | RequestId;
 
 	if (!pdev || !pdev->LibusbConfig || !pdev->urbdrc)
@@ -1336,6 +1330,7 @@ static int libusb_udev_bulk_or_interrupt_transfer(IUDEVICE* idev,
 		async_transfer_user_data_free(user_data);
 		return -1;
 	}
+	transfer->user_data = user_data;
 
 	ep_desc = func_get_ep_desc(pdev->LibusbConfig, pdev->MsConfig, EndpointAddress);
 
@@ -1395,7 +1390,7 @@ static int libusb_udev_bulk_or_interrupt_transfer(IUDEVICE* idev,
 
 static int func_cancel_xact_request(URBDRC_PLUGIN* urbdrc, struct libusb_transfer* transfer)
 {
-	int status;
+	int status = 0;
 
 	if (!urbdrc || !transfer)
 		return -1;
@@ -1416,7 +1411,7 @@ static int func_cancel_xact_request(URBDRC_PLUGIN* urbdrc, struct libusb_transfe
 static void libusb_udev_cancel_all_transfer_request(IUDEVICE* idev)
 {
 	UDEVICE* pdev = (UDEVICE*)idev;
-	size_t count, x;
+	size_t count = 0;
 
 	if (!pdev || !pdev->request_queue || !pdev->urbdrc)
 		return;
@@ -1424,7 +1419,7 @@ static void libusb_udev_cancel_all_transfer_request(IUDEVICE* idev)
 	ArrayList_Lock(pdev->request_queue);
 	count = ArrayList_Count(pdev->request_queue);
 
-	for (x = 0; x < count; x++)
+	for (size_t x = 0; x < count; x++)
 	{
 		struct libusb_transfer* transfer = ArrayList_GetItem(pdev->request_queue, x);
 		func_cancel_xact_request(pdev->urbdrc, transfer);
@@ -1437,7 +1432,7 @@ static int libusb_udev_cancel_transfer_request(IUDEVICE* idev, UINT32 RequestId)
 {
 	int rc = -1;
 	UDEVICE* pdev = (UDEVICE*)idev;
-	struct libusb_transfer* transfer;
+	struct libusb_transfer* transfer = NULL;
 	uint32_t cancelID1 = 0x40000000 | RequestId;
 	uint32_t cancelID2 = 0x80000000 | RequestId;
 
@@ -1493,9 +1488,9 @@ static void udev_set_UsbDevice(IUDEVICE* idev, UINT32 val)
 
 static void udev_free(IUDEVICE* idev)
 {
-	int rc;
+	int rc = 0;
 	UDEVICE* udev = (UDEVICE*)idev;
-	URBDRC_PLUGIN* urbdrc;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!idev || !udev->urbdrc)
 		return;
@@ -1575,7 +1570,6 @@ static int udev_get_device_handle(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UD
                                   UINT16 bus_number, UINT16 dev_number)
 {
 	int error = -1;
-	ssize_t i;
 	uint8_t port_numbers[16] = { 0 };
 	LIBUSB_DEVICE** libusb_list = NULL;
 	const ssize_t total_device = libusb_get_device_list(ctx, &libusb_list);
@@ -1583,7 +1577,7 @@ static int udev_get_device_handle(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UD
 	WINPR_ASSERT(urbdrc);
 
 	/* Look for device. */
-	for (i = 0; i < total_device; i++)
+	for (ssize_t i = 0; i < total_device; i++)
 	{
 		LIBUSB_DEVICE* dev = libusb_list[i];
 
@@ -1630,7 +1624,6 @@ static int udev_get_hub_handle(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UDEVI
                                UINT16 bus_number, UINT16 dev_number)
 {
 	int error = -1;
-	ssize_t i;
 	LIBUSB_DEVICE** libusb_list = NULL;
 	LIBUSB_DEVICE_HANDLE* handle = NULL;
 	const ssize_t total_device = libusb_get_device_list(ctx, &libusb_list);
@@ -1638,7 +1631,7 @@ static int udev_get_hub_handle(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UDEVI
 	WINPR_ASSERT(urbdrc);
 
 	/* Look for device hub. */
-	for (i = 0; i < total_device; i++)
+	for (ssize_t i = 0; i < total_device; i++)
 	{
 		LIBUSB_DEVICE* dev = libusb_list[i];
 
@@ -1667,7 +1660,7 @@ static int udev_get_hub_handle(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UDEVI
 
 static void request_free(void* value)
 {
-	ASYNC_TRANSFER_USER_DATA* user_data;
+	ASYNC_TRANSFER_USER_DATA* user_data = NULL;
 	struct libusb_transfer* transfer = (struct libusb_transfer*)value;
 	if (!transfer)
 		return;
@@ -1681,10 +1674,10 @@ static void request_free(void* value)
 static IUDEVICE* udev_init(URBDRC_PLUGIN* urbdrc, libusb_context* context, LIBUSB_DEVICE* device,
                            BYTE bus_number, BYTE dev_number)
 {
-	UDEVICE* pdev;
+	UDEVICE* pdev = NULL;
 	int status = LIBUSB_ERROR_OTHER;
-	LIBUSB_DEVICE_DESCRIPTOR* devDescriptor;
-	LIBUSB_CONFIG_DESCRIPTOR* config_temp;
+	LIBUSB_DEVICE_DESCRIPTOR* devDescriptor = NULL;
+	LIBUSB_CONFIG_DESCRIPTOR* config_temp = NULL;
 	LIBUSB_INTERFACE_DESCRIPTOR interface_temp;
 
 	WINPR_ASSERT(urbdrc);
@@ -1796,9 +1789,9 @@ fail:
 size_t udev_new_by_id(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UINT16 idVendor, UINT16 idProduct,
                       IUDEVICE*** devArray)
 {
-	LIBUSB_DEVICE** libusb_list;
-	UDEVICE** array;
-	ssize_t i, total_device;
+	LIBUSB_DEVICE** libusb_list = NULL;
+	UDEVICE** array = NULL;
+	ssize_t total_device = 0;
 	size_t num = 0;
 
 	if (!urbdrc || !devArray)
@@ -1815,7 +1808,7 @@ size_t udev_new_by_id(URBDRC_PLUGIN* urbdrc, libusb_context* ctx, UINT16 idVendo
 	if (!array)
 		goto fail;
 
-	for (i = 0; i < total_device; i++)
+	for (ssize_t i = 0; i < total_device; i++)
 	{
 		LIBUSB_DEVICE* dev = libusb_list[i];
 		LIBUSB_DEVICE_DESCRIPTOR* descriptor = udev_new_descript(urbdrc, dev);
