@@ -19,12 +19,13 @@
 
 #include <memory>
 #include <mutex>
+#include <iostream>
 
 #include <freerdp/config.h>
 
-#include <errno.h>
-#include <stdio.h>
-#include <string.h>
+#include <cerrno>
+#include <cstdio>
+#include <cstring>
 
 #include <freerdp/freerdp.h>
 #include <freerdp/constants.h>
@@ -208,8 +209,7 @@ static const struct sdl_exit_code_map_t sdl_exit_code_map[] = {
 
 static const struct sdl_exit_code_map_t* sdl_map_entry_by_code(int exit_code)
 {
-	size_t x;
-	for (x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
+	for (size_t x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
 	{
 		const struct sdl_exit_code_map_t* cur = &sdl_exit_code_map[x];
 		if (cur->code == exit_code)
@@ -220,8 +220,7 @@ static const struct sdl_exit_code_map_t* sdl_map_entry_by_code(int exit_code)
 
 static const struct sdl_exit_code_map_t* sdl_map_entry_by_error(DWORD error)
 {
-	size_t x;
-	for (x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
+	for (size_t x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
 	{
 		const struct sdl_exit_code_map_t* cur = &sdl_exit_code_map[x];
 		if (cur->error == error)
@@ -274,7 +273,7 @@ static int error_info_to_error(freerdp* instance, DWORD* pcode, char** msg, size
  * It can be used to reset invalidated areas. */
 static BOOL sdl_begin_paint(rdpContext* context)
 {
-	rdpGdi* gdi;
+	rdpGdi* gdi = nullptr;
 	auto sdl = get_context(context);
 
 	WINPR_ASSERT(sdl);
@@ -316,7 +315,7 @@ class SdlEventUpdateTriggerGuard
 	SdlContext* _sdl;
 
   public:
-	SdlEventUpdateTriggerGuard(SdlContext* sdl) : _sdl(sdl)
+	explicit SdlEventUpdateTriggerGuard(SdlContext* sdl) : _sdl(sdl)
 	{
 	}
 	~SdlEventUpdateTriggerGuard()
@@ -325,57 +324,49 @@ class SdlEventUpdateTriggerGuard
 	}
 };
 
-static BOOL sdl_draw_to_window_rect(SdlContext* sdl, SDL_Surface* screen, SDL_Surface* surface,
+static bool sdl_draw_to_window_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
                                     SDL_Point offset, const SDL_Rect& srcRect)
 {
 	SDL_Rect dstRect = { offset.x + srcRect.x, offset.y + srcRect.y, srcRect.w, srcRect.h };
-	SDL_SetClipRect(surface, &srcRect);
-	SDL_SetClipRect(screen, &dstRect);
-	SDL_BlitSurface(surface, &srcRect, screen, &dstRect);
-	return TRUE;
+	return window.blit(surface, srcRect, dstRect);
 }
 
-static BOOL sdl_draw_to_window_rect(SdlContext* sdl, SDL_Surface* screen, SDL_Surface* surface,
+static bool sdl_draw_to_window_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
                                     SDL_Point offset, const std::vector<SDL_Rect>& rects = {})
 {
 	if (rects.empty())
 	{
-		return sdl_draw_to_window_rect(sdl, screen, surface, offset,
+		return sdl_draw_to_window_rect(sdl, window, surface, offset,
 		                               { 0, 0, surface->w, surface->h });
 	}
 	for (auto& srcRect : rects)
 	{
-		if (!sdl_draw_to_window_rect(sdl, screen, surface, offset, srcRect))
-			return FALSE;
+		if (!sdl_draw_to_window_rect(sdl, window, surface, offset, srcRect))
+			return false;
 	}
-	return TRUE;
+	return true;
 }
 
-static BOOL sdl_draw_to_window_scaled_rect(SdlContext* sdl, Sint32 windowId, SDL_Surface* screen,
-                                           SDL_Surface* surface, const SDL_Rect& srcRect)
+static bool sdl_draw_to_window_scaled_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
+                                           const SDL_Rect& srcRect)
 {
 	SDL_Rect dstRect = srcRect;
-	sdl_scale_coordinates(sdl, windowId, &dstRect.x, &dstRect.y, FALSE, TRUE);
-	sdl_scale_coordinates(sdl, windowId, &dstRect.w, &dstRect.h, FALSE, TRUE);
-	SDL_SetClipRect(surface, &srcRect);
-	SDL_SetClipRect(screen, &dstRect);
-	SDL_BlitScaled(surface, &srcRect, screen, &dstRect);
-
-	return TRUE;
+	sdl_scale_coordinates(sdl, window.id(), &dstRect.x, &dstRect.y, FALSE, TRUE);
+	sdl_scale_coordinates(sdl, window.id(), &dstRect.w, &dstRect.h, FALSE, TRUE);
+	return window.blit(surface, srcRect, dstRect);
 }
 
-static BOOL sdl_draw_to_window_scaled_rect(SdlContext* sdl, Sint32 windowId, SDL_Surface* screen,
-                                           SDL_Surface* surface,
+static BOOL sdl_draw_to_window_scaled_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
                                            const std::vector<SDL_Rect>& rects = {})
 {
 	if (rects.empty())
 	{
-		return sdl_draw_to_window_scaled_rect(sdl, windowId, screen, surface,
+		return sdl_draw_to_window_scaled_rect(sdl, window, surface,
 		                                      { 0, 0, surface->w, surface->h });
 	}
-	for (auto& srcRect : rects)
+	for (const auto& srcRect : rects)
 	{
-		if (!sdl_draw_to_window_scaled_rect(sdl, windowId, screen, surface, srcRect))
+		if (!sdl_draw_to_window_scaled_rect(sdl, window, surface, srcRect))
 			return FALSE;
 	}
 	return TRUE;
@@ -389,44 +380,39 @@ static BOOL sdl_draw_to_window(SdlContext* sdl, SdlWindow& window,
 	auto context = sdl->context();
 	auto gdi = context->gdi;
 
-	SDL_Surface* screen = SDL_GetWindowSurface(window.window());
-
-	int w, h;
-	SDL_GetWindowSize(window.window(), &w, &h);
+	auto size = window.rect();
 
 	if (!freerdp_settings_get_bool(context->settings, FreeRDP_SmartSizing))
 	{
-		if (gdi->width < w)
+		if (gdi->width < size.w)
 		{
-			window.setOffsetX((w - gdi->width) / 2);
+			window.setOffsetX((size.w - gdi->width) / 2);
 		}
-		if (gdi->height < h)
+		if (gdi->height < size.h)
 		{
-			window.setOffsetY((h - gdi->height) / 2);
+			window.setOffsetY((size.h - gdi->height) / 2);
 		}
 
 		auto surface = sdl->primary.get();
-		if (!sdl_draw_to_window_rect(sdl, screen, surface, { window.offsetX(), window.offsetY() },
+		if (!sdl_draw_to_window_rect(sdl, window, surface, { window.offsetX(), window.offsetY() },
 		                             rects))
 			return FALSE;
 	}
 	else
 	{
-		auto id = SDL_GetWindowID(window.window());
-
-		if (!sdl_draw_to_window_scaled_rect(sdl, id, screen, sdl->primary.get(), rects))
+		if (!sdl_draw_to_window_scaled_rect(sdl, window, sdl->primary.get(), rects))
 			return FALSE;
 	}
-	SDL_UpdateWindowSurface(window.window());
+	window.updateSurface();
 	return TRUE;
 }
 
-static BOOL sdl_draw_to_window(SdlContext* sdl, std::vector<SdlWindow>& windows,
+static BOOL sdl_draw_to_window(SdlContext* sdl, std::map<Uint32, SdlWindow>& windows,
                                const std::vector<SDL_Rect>& rects = {})
 {
 	for (auto& window : windows)
 	{
-		if (!sdl_draw_to_window(sdl, window, rects))
+		if (!sdl_draw_to_window(sdl, window.second, rects))
 			return FALSE;
 	}
 
@@ -435,7 +421,7 @@ static BOOL sdl_draw_to_window(SdlContext* sdl, std::vector<SdlWindow>& windows,
 
 static BOOL sdl_end_paint_process(rdpContext* context)
 {
-	rdpGdi* gdi;
+	rdpGdi* gdi = nullptr;
 	auto sdl = get_context(context);
 
 	WINPR_ASSERT(context);
@@ -493,7 +479,7 @@ static void sdl_destroy_primary(SdlContext* sdl)
 /* Create a SDL surface from the GDI buffer */
 static BOOL sdl_create_primary(SdlContext* sdl)
 {
-	rdpGdi* gdi;
+	rdpGdi* gdi = nullptr;
 
 	WINPR_ASSERT(sdl);
 
@@ -521,8 +507,8 @@ static BOOL sdl_create_primary(SdlContext* sdl)
 
 static BOOL sdl_desktop_resize(rdpContext* context)
 {
-	rdpGdi* gdi;
-	rdpSettings* settings;
+	rdpGdi* gdi = nullptr;
+	rdpSettings* settings = nullptr;
 	auto sdl = get_context(context);
 
 	WINPR_ASSERT(sdl);
@@ -601,7 +587,7 @@ static BOOL sdl_pre_connect(freerdp* instance)
 
 		std::lock_guard<CriticalSection> lock(sdl->critical);
 		if (!freerdp_settings_get_bool(settings, FreeRDP_UseCommonStdioCallbacks))
-			sdl->connection_dialog.reset(new SDLConnectionDialog(instance->context));
+			sdl->connection_dialog = std::make_unique<SDLConnectionDialog>(instance->context);
 		if (sdl->connection_dialog)
 		{
 			sdl->connection_dialog->setTitle("Connecting to '%s'",
@@ -643,10 +629,10 @@ static BOOL sdl_pre_connect(freerdp* instance)
 
 static const char* sdl_window_get_title(rdpSettings* settings)
 {
-	const char* windowTitle;
-	UINT32 port;
-	BOOL addPort;
-	const char* name;
+	const char* windowTitle = nullptr;
+	UINT32 port = 0;
+	BOOL addPort = 0;
+	const char* name = nullptr;
 	const char* prefix = "FreeRDP:";
 
 	if (!settings)
@@ -654,7 +640,7 @@ static const char* sdl_window_get_title(rdpSettings* settings)
 
 	windowTitle = freerdp_settings_get_string(settings, FreeRDP_WindowTitle);
 	if (windowTitle)
-		return _strdup(windowTitle);
+		return windowTitle;
 
 	name = freerdp_settings_get_server_name(settings);
 	port = freerdp_settings_get_uint32(settings, FreeRDP_ServerPort);
@@ -668,7 +654,8 @@ static const char* sdl_window_get_title(rdpSettings* settings)
 	else
 		sprintf_s(buffer, sizeof(buffer), "%s %s:%" PRIu32, prefix, name, port);
 
-	freerdp_settings_set_string(settings, FreeRDP_WindowTitle, buffer);
+	if (!freerdp_settings_set_string(settings, FreeRDP_WindowTitle, buffer))
+		return nullptr;
 	return freerdp_settings_get_string(settings, FreeRDP_WindowTitle);
 }
 
@@ -753,14 +740,12 @@ static BOOL sdl_create_windows(SdlContext* sdl)
 
 		if (freerdp_settings_get_bool(settings, FreeRDP_UseMultimon))
 		{
-			int win_x;
-			int win_y;
-			SDL_GetWindowPosition(window.window(), &win_x, &win_y);
-			window.setOffsetX(0 - win_x);
-			window.setOffsetY(0 - win_y);
+			auto r = window.rect();
+			window.setOffsetX(0 - r.x);
+			window.setOffsetY(0 - r.y);
 		}
 
-		sdl->windows.emplace_back(std::move(window));
+		sdl->windows.insert({ window.id(), std::move(window) });
 	}
 
 	rc = TRUE;
@@ -816,7 +801,7 @@ static int sdl_run(SdlContext* sdl)
 			return -1;
 	}
 
-	SDL_Init(SDL_INIT_EVERYTHING);
+	SDL_Init(SDL_INIT_VIDEO);
 	TTF_Init();
 #if SDL_VERSION_ATLEAST(2, 0, 16)
 	SDL_SetHint(SDL_HINT_ALLOW_ALT_TAB_WHILE_GRABBED, "0");
@@ -850,6 +835,11 @@ static int sdl_run(SdlContext* sdl)
 			        windowEvent.type);
 #endif
 			std::lock_guard<CriticalSection> lock(sdl->critical);
+			/* The session might have been disconnected while we were waiting for a new SDL event.
+			 * In that case ignore the SDL event and terminate. */
+			if (freerdp_shall_disconnect_context(sdl->context()))
+				continue;
+
 			if (sdl->connection_dialog)
 			{
 				if (sdl->connection_dialog->handle(windowEvent))
@@ -929,19 +919,22 @@ static int sdl_run(SdlContext* sdl)
 						case SDL_WINDOWEVENT_RESIZED:
 						case SDL_WINDOWEVENT_SIZE_CHANGED:
 						{
-							auto window = SDL_GetWindowFromID(ev->windowID);
-
-							if (window)
+							auto window = sdl->windows.find(ev->windowID);
+							if (window != sdl->windows.end())
 							{
-								auto surface = SDL_GetWindowSurface(window);
-								if (surface)
-								{
-									SDL_Rect rect = { 0, 0, surface->w, surface->h };
-
-									auto color = SDL_MapRGBA(surface->format, 0, 0, 0, 0xff);
-									SDL_FillRect(surface, &rect, color);
-								}
-								sdl_draw_to_window(sdl, sdl->windows);
+								window->second.fill();
+								window->second.updateSurface();
+							}
+						}
+						break;
+						case SDL_WINDOWEVENT_MOVED:
+						{
+							auto window = sdl->windows.find(ev->windowID);
+							if (window != sdl->windows.end())
+							{
+								auto r = window->second.rect();
+								auto id = window->second.id();
+								WLog_DBG(SDL_TAG, "%lu: %dx%d-%dx%d", id, r.x, r.y, r.w, r.h);
 							}
 						}
 						break;
@@ -999,53 +992,18 @@ static int sdl_run(SdlContext* sdl)
 				break;
 				case SDL_USEREVENT_WINDOW_RESIZEABLE:
 				{
-					auto window = static_cast<SDL_Window*>(windowEvent.user.data1);
+					auto window = static_cast<SdlWindow*>(windowEvent.user.data1);
 					const SDL_bool use = windowEvent.user.code != 0 ? SDL_TRUE : SDL_FALSE;
-					SDL_SetWindowResizable(window, use);
+					if (window)
+						window->resizeable(use);
 				}
 				break;
 				case SDL_USEREVENT_WINDOW_FULLSCREEN:
 				{
-					auto window = static_cast<SDL_Window*>(windowEvent.user.data1);
+					auto window = static_cast<SdlWindow*>(windowEvent.user.data1);
 					const SDL_bool enter = windowEvent.user.code != 0 ? SDL_TRUE : SDL_FALSE;
-
-					Uint32 curFlags = SDL_GetWindowFlags(window);
-
-					if (enter)
-					{
-						if (!(curFlags & SDL_WINDOW_BORDERLESS))
-						{
-							auto idx = SDL_GetWindowDisplayIndex(window);
-							SDL_DisplayMode mode = {};
-							SDL_GetCurrentDisplayMode(idx, &mode);
-
-							SDL_RestoreWindow(window); // Maximize so we can see the caption and
-							                           // bits
-							SDL_SetWindowBordered(window, SDL_FALSE);
-							SDL_SetWindowPosition(window, 0, 0);
-#if SDL_VERSION_ATLEAST(2, 0, 16)
-							SDL_SetWindowAlwaysOnTop(window, SDL_TRUE);
-#endif
-							SDL_RaiseWindow(window);
-							SDL_SetWindowSize(window, mode.w, mode.h);
-						}
-					}
-					else
-					{
-						if (curFlags & SDL_WINDOW_BORDERLESS)
-						{
-
-							SDL_SetWindowBordered(window, SDL_TRUE);
-#if SDL_VERSION_ATLEAST(2, 0, 16)
-							SDL_SetWindowAlwaysOnTop(window, SDL_FALSE);
-#endif
-							SDL_RaiseWindow(window);
-							SDL_MinimizeWindow(
-							    window); // Maximize so we can see the caption and bits
-							SDL_MaximizeWindow(
-							    window); // Maximize so we can see the caption and bits
-						}
-					}
+					if (window)
+						window->fullscreen(enter);
 				}
 				break;
 				case SDL_USEREVENT_POINTER_NULL:
@@ -1060,9 +1018,9 @@ static int sdl_run(SdlContext* sdl)
 				break;
 				case SDL_USEREVENT_POINTER_POSITION:
 				{
-					const INT32 x =
+					const auto x =
 					    static_cast<INT32>(reinterpret_cast<uintptr_t>(windowEvent.user.data1));
-					const INT32 y =
+					const auto y =
 					    static_cast<INT32>(reinterpret_cast<uintptr_t>(windowEvent.user.data2));
 
 					SDL_Window* window = SDL_GetMouseFocus();
@@ -1192,10 +1150,10 @@ static void sdl_post_final_disconnect(freerdp* instance)
  * after the connection ends. */
 static DWORD WINAPI sdl_client_thread_proc(SdlContext* sdl)
 {
-	DWORD nCount;
-	DWORD status;
+	DWORD nCount = 0;
+	DWORD status = 0;
 	int exit_code = SDL_EXIT_SUCCESS;
-	char* error_msg = NULL;
+	char* error_msg = nullptr;
 	size_t error_msg_len = 0;
 
 	HANDLE handles[MAXIMUM_WAIT_OBJECTS] = {};
@@ -1593,10 +1551,62 @@ static void SDLCALL winpr_LogOutputFunction(void* userdata, int category, SDL_Lo
 	                  category2str(category), message);
 }
 
+static void print_config_file_help()
+{
+#if defined(CJSON_FOUND)
+	std::cout << "CONFIGURATION FILE" << std::endl;
+	std::cout << std::endl;
+	std::cout << "  The SDL client supports some user defined configuration options." << std::endl;
+	std::cout << "  Settings are stored in JSON format" << std::endl;
+	std::cout << "  The location is a per user file. Location for current user is "
+	          << sdl_get_pref_file() << std::endl;
+	std::cout
+	    << "  The XDG_CONFIG_HOME environment variable can be used to override the base directory."
+	    << std::endl;
+	std::cout << std::endl;
+	std::cout << "  The following configuration options are supported:" << std::endl;
+	std::cout << std::endl;
+	std::cout << "    SDL_KeyModMask" << std::endl;
+	std::cout << "      Defines the key combination required for SDL client shortcuts."
+	          << std::endl;
+	std::cout << "      Default KMOD_RSHIFT" << std::endl;
+	std::cout << "      An array of SDL_Keymod strings as defined at "
+	             "https://wiki.libsdl.org/SDL2/SDL_Keymod"
+	          << std::endl;
+	std::cout << std::endl;
+	std::cout << "    SDL_Fullscreen" << std::endl;
+	std::cout << "      Toggles client fullscreen state." << std::endl;
+	std::cout << "      Default SDL_SCANCODE_RETURN." << std::endl;
+	std::cout << "      A string as "
+	             "defined at https://wiki.libsdl.org/SDL2/SDLScancodeLookup"
+	          << std::endl;
+	std::cout << std::endl;
+	std::cout << "    SDL_Resizeable" << std::endl;
+	std::cout << "      Toggles local window resizeable state." << std::endl;
+	std::cout << "      Default SDL_SCANCODE_R." << std::endl;
+	std::cout << "      A string as "
+	             "defined at https://wiki.libsdl.org/SDL2/SDLScancodeLookup"
+	          << std::endl;
+	std::cout << std::endl;
+	std::cout << "    SDL_Grab" << std::endl;
+	std::cout << "      Toggles keyboard and mouse grab state." << std::endl;
+	std::cout << "      Default SDL_SCANCODE_G." << std::endl;
+	std::cout << "      A string as "
+	             "defined at https://wiki.libsdl.org/SDL2/SDLScancodeLookup"
+	          << std::endl;
+	std::cout << std::endl;
+	std::cout << "    SDL_Disconnect" << std::endl;
+	std::cout << "      Disconnects from the RDP session." << std::endl;
+	std::cout << "      Default SDL_SCANCODE_D." << std::endl;
+	std::cout << "      A string as defined at https://wiki.libsdl.org/SDL2/SDLScancodeLookup"
+	          << std::endl;
+#endif
+}
+
 int main(int argc, char* argv[])
 {
 	int rc = -1;
-	int status;
+	int status = 0;
 	RDP_CLIENT_ENTRY_POINTS clientEntryPoints = {};
 
 	freerdp_client_warn_experimental(argc, argv);
@@ -1617,6 +1627,7 @@ int main(int argc, char* argv[])
 	if (status)
 	{
 		rc = freerdp_client_settings_command_line_status_print(settings, status, argc, argv);
+		print_config_file_help();
 		if (freerdp_settings_get_bool(settings, FreeRDP_ListMonitors))
 			sdl_list_monitors(sdl);
 		return rc;
@@ -1650,7 +1661,7 @@ BOOL SdlContext::update_fullscreen(BOOL enter)
 	std::lock_guard<CriticalSection> lock(critical);
 	for (const auto& window : windows)
 	{
-		if (!sdl_push_user_event(SDL_USEREVENT_WINDOW_FULLSCREEN, window.window(), enter))
+		if (!sdl_push_user_event(SDL_USEREVENT_WINDOW_FULLSCREEN, &window.second, enter))
 			return FALSE;
 	}
 	fullscreen = enter;
@@ -1668,7 +1679,7 @@ BOOL SdlContext::update_resizeable(BOOL enable)
 
 	for (const auto& window : windows)
 	{
-		if (!sdl_push_user_event(SDL_USEREVENT_WINDOW_RESIZEABLE, window.window(), use))
+		if (!sdl_push_user_event(SDL_USEREVENT_WINDOW_RESIZEABLE, &window.second, use))
 			return FALSE;
 	}
 	resizeable = use;
