@@ -24,6 +24,7 @@
 
 #include <freerdp/config.h>
 
+#include <math.h>
 #include <winpr/assert.h>
 #include <winpr/sspicli.h>
 
@@ -35,7 +36,6 @@
 
 #ifdef WITH_XRENDER
 #include <X11/extensions/Xrender.h>
-#include <math.h>
 #endif
 
 #ifdef WITH_XI
@@ -83,12 +83,10 @@
 #include <freerdp/client/cmdline.h>
 
 #include <winpr/crt.h>
-#include <winpr/assert.h>
 #include <winpr/synch.h>
 #include <winpr/file.h>
 #include <winpr/print.h>
 #include <winpr/sysinfo.h>
-#include <X11/XKBlib.h>
 
 #include "xf_rail.h"
 #if defined(CHANNEL_TSMF_CLIENT)
@@ -102,7 +100,6 @@
 #include "xf_monitor.h"
 #include "xf_graphics.h"
 #include "xf_keyboard.h"
-#include "xf_input.h"
 #include "xf_channels.h"
 #include "xfreerdp.h"
 #include "xf_utils.h"
@@ -153,8 +150,7 @@ static void xf_teardown_x11(xfContext* xfc);
 
 static int xf_map_error_to_exit_code(DWORD error)
 {
-	size_t x;
-	for (x = 0; x < ARRAYSIZE(xf_exit_code_map); x++)
+	for (size_t x = 0; x < ARRAYSIZE(xf_exit_code_map); x++)
 	{
 		const struct xf_exit_code_map_t* cur = &xf_exit_code_map[x];
 		if (cur->error == error)
@@ -173,16 +169,16 @@ static BOOL xf_get_pixmap_info(xfContext* xfc);
 static void xf_draw_screen_scaled(xfContext* xfc, int x, int y, int w, int h)
 {
 	XTransform transform;
-	Picture windowPicture;
-	Picture primaryPicture;
+	Picture windowPicture = 0;
+	Picture primaryPicture = 0;
 	XRenderPictureAttributes pa;
-	XRenderPictFormat* picFormat;
-	double xScalingFactor;
-	double yScalingFactor;
-	int x2;
-	int y2;
-	const char* filter;
-	rdpSettings* settings;
+	XRenderPictFormat* picFormat = NULL;
+	double xScalingFactor = NAN;
+	double yScalingFactor = NAN;
+	int x2 = 0;
+	int y2 = 0;
+	const char* filter = NULL;
+	rdpSettings* settings = NULL;
 	WINPR_ASSERT(xfc);
 
 	settings = xfc->common.context.settings;
@@ -271,7 +267,7 @@ static void xf_draw_screen_scaled(xfContext* xfc, int x, int y, int w, int h)
 
 BOOL xf_picture_transform_required(xfContext* xfc)
 {
-	rdpSettings* settings;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(xfc);
 
@@ -324,7 +320,7 @@ void xf_draw_screen_(xfContext* xfc, int x, int y, int w, int h, const char* fkt
 
 static BOOL xf_desktop_resize(rdpContext* context)
 {
-	rdpSettings* settings;
+	rdpSettings* settings = NULL;
 	xfContext* xfc = (xfContext*)context;
 
 	WINPR_ASSERT(xfc);
@@ -518,9 +514,9 @@ static BOOL xf_process_x_events(freerdp* instance)
 
 static char* xf_window_get_title(rdpSettings* settings)
 {
-	BOOL port;
-	char* windowTitle;
-	size_t size;
+	BOOL port = 0;
+	char* windowTitle = NULL;
+	size_t size = 0;
 	const char* prefix = "FreeRDP:";
 
 	if (!settings)
@@ -880,7 +876,9 @@ static BOOL xf_play_sound(rdpContext* context, const PLAY_SOUND_UPDATE* play_sou
 
 static void xf_check_extensions(xfContext* context)
 {
-	int xkb_opcode, xkb_event, xkb_error;
+	int xkb_opcode = 0;
+	int xkb_event = 0;
+	int xkb_error = 0;
 	int xkb_major = XkbMajorVersion;
 	int xkb_minor = XkbMinorVersion;
 
@@ -893,8 +891,8 @@ static void xf_check_extensions(xfContext* context)
 
 #ifdef WITH_XRENDER
 	{
-		int xrender_event_base;
-		int xrender_error_base;
+		int xrender_event_base = 0;
+		int xrender_error_base = 0;
 
 		if (XRenderQueryExtension(context->display, &xrender_event_base, &xrender_error_base))
 		{
@@ -914,12 +912,14 @@ static const size_t TEST_PTR_LEN = sizeof(TEST_PTR_STR) / sizeof(char);
 static void xf_get_x11_button_map(xfContext* xfc, unsigned char* x11_map)
 {
 #ifdef WITH_XI
-	int opcode, event, error;
-	XDevice* ptr_dev;
-	XExtensionVersion* version;
-	XDeviceInfo* devices1;
-	XIDeviceInfo* devices2;
-	int i, num_devices;
+	int opcode = 0;
+	int event = 0;
+	int error = 0;
+	XDevice* ptr_dev = NULL;
+	XExtensionVersion* version = NULL;
+	XDeviceInfo* devices1 = NULL;
+	XIDeviceInfo* devices2 = NULL;
+	int num_devices = 0;
 
 	if (XQueryExtension(xfc->display, "XInputExtension", &opcode, &event, &error))
 	{
@@ -935,7 +935,7 @@ static void xf_get_x11_button_map(xfContext* xfc, unsigned char* x11_map)
 
 			if (devices2)
 			{
-				for (i = 0; i < num_devices; ++i)
+				for (int i = 0; i < num_devices; ++i)
 				{
 					if ((devices2[i].use == XISlavePointer) &&
 					    (strncmp(devices2[i].name, TEST_PTR_STR, TEST_PTR_LEN) != 0))
@@ -956,7 +956,7 @@ static void xf_get_x11_button_map(xfContext* xfc, unsigned char* x11_map)
 
 			if (devices1)
 			{
-				for (i = 0; i < num_devices; ++i)
+				for (int i = 0; i < num_devices; ++i)
 				{
 					if ((devices1[i].use == IsXExtensionPointer) &&
 					    (strncmp(devices1[i].name, TEST_PTR_STR, TEST_PTR_LEN) != 0))
@@ -1013,9 +1013,7 @@ static const button_map xf_button_flags[NUM_BUTTONS_MAPPED] = {
 
 static UINT16 get_flags_for_button(int button)
 {
-	size_t x;
-
-	for (x = 0; x < ARRAYSIZE(xf_button_flags); x++)
+	for (size_t x = 0; x < ARRAYSIZE(xf_button_flags); x++)
 	{
 		const button_map* map = &xf_button_flags[x];
 
@@ -1030,7 +1028,7 @@ static void xf_button_map_init(xfContext* xfc)
 {
 	size_t pos = 0;
 	/* loop counter for array initialization */
-	size_t physical;
+
 	/* logical mouse button which is used for each physical mouse  */
 	/* button (indexed from zero). This is the default map.        */
 	unsigned char x11_map[112] = { 0 };
@@ -1059,7 +1057,7 @@ static void xf_button_map_init(xfContext* xfc)
 	/* iterate over all (mapped) physical buttons; for each of them */
 	/* find the logical button in X11, and assign to this the       */
 	/* appropriate value to send over the RDP wire.                 */
-	for (physical = 0; physical < ARRAYSIZE(x11_map); ++physical)
+	for (size_t physical = 0; physical < ARRAYSIZE(x11_map); ++physical)
 	{
 		const unsigned char logical = x11_map[physical];
 		const UINT16 flags = get_flags_for_button(logical);
@@ -1093,10 +1091,10 @@ static void xf_button_map_init(xfContext* xfc)
  */
 static BOOL xf_pre_connect(freerdp* instance)
 {
-	rdpChannels* channels;
-	rdpSettings* settings;
-	rdpContext* context;
-	xfContext* xfc;
+	rdpChannels* channels = NULL;
+	rdpSettings* settings = NULL;
+	rdpContext* context = NULL;
+	xfContext* xfc = NULL;
 	UINT32 maxWidth = 0;
 	UINT32 maxHeight = 0;
 
@@ -1228,7 +1226,9 @@ static BOOL xf_process_pipe(rdpContext* context, const char* pipe)
 	int fd = open(pipe, O_NONBLOCK | O_RDONLY);
 	if (fd < 0)
 	{
-		WLog_ERR(TAG, "pipe '%s' open returned %s [%d]", pipe, strerror(errno), errno);
+		char ebuffer[256] = { 0 };
+		WLog_ERR(TAG, "pipe '%s' open returned %s [%d]", pipe,
+		         winpr_strerror(errno, ebuffer, sizeof(ebuffer)), errno);
 		return FALSE;
 	}
 	while (!freerdp_shall_disconnect_context(context))
@@ -1237,6 +1237,7 @@ static BOOL xf_process_pipe(rdpContext* context, const char* pipe)
 		ssize_t rd = read(fd, buffer, sizeof(buffer) - 1);
 		if (rd == 0)
 		{
+			char ebuffer[256] = { 0 };
 			if ((errno == EAGAIN) || (errno == 0))
 			{
 				Sleep(100);
@@ -1244,12 +1245,15 @@ static BOOL xf_process_pipe(rdpContext* context, const char* pipe)
 			}
 
 			// EOF, abort reading.
-			WLog_ERR(TAG, "pipe '%s' read returned %s [%d]", pipe, strerror(errno), errno);
+			WLog_ERR(TAG, "pipe '%s' read returned %s [%d]", pipe,
+			         winpr_strerror(errno, ebuffer, sizeof(ebuffer)), errno);
 			break;
 		}
 		else if (rd < 0)
 		{
-			WLog_ERR(TAG, "pipe '%s' read returned %s [%d]", pipe, strerror(errno), errno);
+			char ebuffer[256] = { 0 };
+			WLog_ERR(TAG, "pipe '%s' read returned %s [%d]", pipe,
+			         winpr_strerror(errno, ebuffer, sizeof(ebuffer)), errno);
 			break;
 		}
 		else
@@ -1287,7 +1291,9 @@ static DWORD WINAPI xf_handle_pipe(void* arg)
 	const int rc = mkfifo(pipe, S_IWUSR | S_IRUSR);
 	if (rc != 0)
 	{
-		WLog_ERR(TAG, "Failed to create named pipe '%s': %s [%d]", pipe, strerror(errno), errno);
+		char ebuffer[256] = { 0 };
+		WLog_ERR(TAG, "Failed to create named pipe '%s': %s [%d]", pipe,
+		         winpr_strerror(errno, ebuffer, sizeof(ebuffer)), errno);
 		return 0;
 	}
 	freerdp_add_signal_cleanup_handler(pipe, cleanup_pipe);
@@ -1393,8 +1399,8 @@ static BOOL xf_post_connect(freerdp* instance)
 
 static void xf_post_disconnect(freerdp* instance)
 {
-	xfContext* xfc;
-	rdpContext* context;
+	xfContext* xfc = NULL;
+	rdpContext* context = NULL;
 
 	if (!instance || !instance->context)
 		return;
@@ -1435,8 +1441,8 @@ static void xf_post_disconnect(freerdp* instance)
 
 static void xf_post_final_disconnect(freerdp* instance)
 {
-	xfContext* xfc;
-	rdpContext* context;
+	xfContext* xfc = NULL;
+	rdpContext* context = NULL;
 
 	if (!instance || !instance->context)
 		return;
@@ -1675,8 +1681,9 @@ static void xf_TerminateEventHandler(void* context, const TerminateEventArgs* e)
 #ifdef WITH_XRENDER
 static void xf_ZoomingChangeEventHandler(void* context, const ZoomingChangeEventArgs* e)
 {
-	int w, h;
-	rdpSettings* settings;
+	int w = 0;
+	int h = 0;
+	rdpSettings* settings = NULL;
 	xfContext* xfc = (xfContext*)context;
 
 	WINPR_ASSERT(xfc);
@@ -1708,7 +1715,7 @@ static void xf_ZoomingChangeEventHandler(void* context, const ZoomingChangeEvent
 static void xf_PanningChangeEventHandler(void* context, const PanningChangeEventArgs* e)
 {
 	xfContext* xfc = (xfContext*)context;
-	rdpSettings* settings;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(xfc);
 	WINPR_ASSERT(e);
@@ -1766,10 +1773,9 @@ static int xfreerdp_client_start(rdpContext* context)
 
 static Atom get_supported_atom(xfContext* xfc, const char* atomName)
 {
-	unsigned long i;
 	const Atom atom = XInternAtom(xfc->display, atomName, False);
 
-	for (i = 0; i < xfc->supportedAtomCount; i++)
+	for (unsigned long i = 0; i < xfc->supportedAtomCount; i++)
 	{
 		if (xfc->supportedAtoms[i] == atom)
 			return atom;
@@ -1868,7 +1874,8 @@ BOOL xf_setup_x11(xfContext* xfc)
 	{
 		Atom actual_type = 0;
 		int actual_format = 0;
-		unsigned long nitems = 0, after = 0;
+		unsigned long nitems = 0;
+		unsigned long after = 0;
 		unsigned char* data = NULL;
 		int status = LogTagAndXGetWindowProperty(
 		    TAG, xfc->display, RootWindowOfScreen(xfc->screen), xfc->_NET_SUPPORTED, 0, 1024, False,
