@@ -167,17 +167,16 @@ static INLINE INT32 planar_skip_plane_rle(const BYTE* pSrcData, UINT32 SrcSize,
                                           UINT32 nHeight)
 {
 	UINT32 used = 0;
-	UINT32 x, y;
-	BYTE controlByte;
+	BYTE controlByte = 0;
 
 	WINPR_ASSERT(pSrcData);
 
-	for (y = 0; y < nHeight; y++)
+	for (UINT32 y = 0; y < nHeight; y++)
 	{
-		for (x = 0; x < nWidth;)
+		for (UINT32 x = 0; x < nWidth;)
 		{
-			int cRawBytes;
-			int nRunLength;
+			int cRawBytes = 0;
+			int nRunLength = 0;
 
 			if (used >= SrcSize)
 			{
@@ -231,14 +230,13 @@ static INLINE INT32 planar_skip_plane_rle(const BYTE* pSrcData, UINT32 SrcSize,
 static INLINE INT32 planar_decompress_plane_rle_only(const BYTE* pSrcData, UINT32 SrcSize,
                                                      BYTE* pDstData, UINT32 nWidth, UINT32 nHeight)
 {
-	INT32 x, y;
-	UINT32 pixel;
-	UINT32 cRawBytes;
-	UINT32 nRunLength;
-	INT32 deltaValue;
-	BYTE controlByte;
-	BYTE* currentScanline;
-	BYTE* previousScanline;
+	UINT32 pixel = 0;
+	UINT32 cRawBytes = 0;
+	UINT32 nRunLength = 0;
+	INT32 deltaValue = 0;
+	BYTE controlByte = 0;
+	BYTE* currentScanline = NULL;
+	BYTE* previousScanline = NULL;
 	const BYTE* srcp = pSrcData;
 
 	WINPR_ASSERT(nHeight <= INT32_MAX);
@@ -246,13 +244,13 @@ static INLINE INT32 planar_decompress_plane_rle_only(const BYTE* pSrcData, UINT3
 
 	previousScanline = NULL;
 
-	for (y = 0; y < (INT32)nHeight; y++)
+	for (INT32 y = 0; y < (INT32)nHeight; y++)
 	{
 		BYTE* dstp = &pDstData[((y) * (INT32)nWidth)];
 		pixel = 0;
 		currentScanline = dstp;
 
-		for (x = 0; x < (INT32)nWidth;)
+		for (INT32 x = 0; x < (INT32)nWidth;)
 		{
 			controlByte = *srcp;
 			srcp++;
@@ -353,15 +351,16 @@ static INLINE INT32 planar_decompress_plane_rle(const BYTE* pSrcData, UINT32 Src
                                                 UINT32 nYDst, UINT32 nWidth, UINT32 nHeight,
                                                 UINT32 nChannel, BOOL vFlip)
 {
-	INT32 x, y;
-	UINT32 pixel;
-	UINT32 cRawBytes;
-	UINT32 nRunLength;
-	INT32 deltaValue;
-	INT32 beg, end, inc;
-	BYTE controlByte;
-	BYTE* currentScanline;
-	BYTE* previousScanline;
+	UINT32 pixel = 0;
+	UINT32 cRawBytes = 0;
+	UINT32 nRunLength = 0;
+	INT32 deltaValue = 0;
+	INT32 beg = 0;
+	INT32 end = 0;
+	INT32 inc = 0;
+	BYTE controlByte = 0;
+	BYTE* currentScanline = NULL;
+	BYTE* previousScanline = NULL;
 	const BYTE* srcp = pSrcData;
 
 	WINPR_ASSERT(nHeight <= INT32_MAX);
@@ -383,13 +382,13 @@ static INLINE INT32 planar_decompress_plane_rle(const BYTE* pSrcData, UINT32 Src
 		inc = 1;
 	}
 
-	for (y = beg; y != end; y += inc)
+	for (INT32 y = beg; y != end; y += inc)
 	{
 		BYTE* dstp = &pDstData[((nYDst + y) * (INT32)nDstStep) + (nXDst * 4) + nChannel];
 		pixel = 0;
 		currentScanline = dstp;
 
-		for (x = 0; x < (INT32)nWidth;)
+		for (INT32 x = 0; x < (INT32)nWidth;)
 		{
 			controlByte = *srcp;
 			srcp++;
@@ -489,8 +488,9 @@ static INLINE INT32 planar_set_plane(BYTE bValue, BYTE* pDstData, INT32 nDstStep
                                      UINT32 nYDst, UINT32 nWidth, UINT32 nHeight, UINT32 nChannel,
                                      BOOL vFlip)
 {
-	INT32 x, y;
-	INT32 beg, end, inc;
+	INT32 beg = 0;
+	INT32 end = 0;
+	INT32 inc = 0;
 
 	WINPR_ASSERT(nHeight <= INT32_MAX);
 	WINPR_ASSERT(nWidth <= INT32_MAX);
@@ -509,11 +509,11 @@ static INLINE INT32 planar_set_plane(BYTE bValue, BYTE* pDstData, INT32 nDstStep
 		inc = 1;
 	}
 
-	for (y = beg; y != end; y += inc)
+	for (INT32 y = beg; y != end; y += inc)
 	{
 		BYTE* dstp = &pDstData[((nYDst + y) * (INT32)nDstStep) + (nXDst * 4) + nChannel];
 
-		for (x = 0; x < (INT32)nWidth; ++x)
+		for (INT32 x = 0; x < (INT32)nWidth; ++x)
 		{
 			*dstp = bValue;
 			dstp += 4;
@@ -526,8 +526,6 @@ static INLINE INT32 planar_set_plane(BYTE bValue, BYTE* pDstData, INT32 nDstStep
 static INLINE BOOL writeLine(BYTE** ppRgba, UINT32 DstFormat, UINT32 width, const BYTE** ppR,
                              const BYTE** ppG, const BYTE** ppB, const BYTE** ppA)
 {
-	UINT32 x;
-
 	WINPR_ASSERT(ppRgba);
 	WINPR_ASSERT(ppR);
 	WINPR_ASSERT(ppG);
@@ -536,7 +534,7 @@ static INLINE BOOL writeLine(BYTE** ppRgba, UINT32 DstFormat, UINT32 width, cons
 	switch (DstFormat)
 	{
 		case PIXEL_FORMAT_BGRA32:
-			for (x = 0; x < width; x++)
+			for (UINT32 x = 0; x < width; x++)
 			{
 				*(*ppRgba)++ = *(*ppB)++;
 				*(*ppRgba)++ = *(*ppG)++;
@@ -547,7 +545,7 @@ static INLINE BOOL writeLine(BYTE** ppRgba, UINT32 DstFormat, UINT32 width, cons
 			return TRUE;
 
 		case PIXEL_FORMAT_BGRX32:
-			for (x = 0; x < width; x++)
+			for (UINT32 x = 0; x < width; x++)
 			{
 				*(*ppRgba)++ = *(*ppB)++;
 				*(*ppRgba)++ = *(*ppG)++;
@@ -560,7 +558,7 @@ static INLINE BOOL writeLine(BYTE** ppRgba, UINT32 DstFormat, UINT32 width, cons
 		default:
 			if (ppA)
 			{
-				for (x = 0; x < width; x++)
+				for (UINT32 x = 0; x < width; x++)
 				{
 					BYTE alpha = *(*ppA)++;
 					UINT32 color =
@@ -573,7 +571,7 @@ static INLINE BOOL writeLine(BYTE** ppRgba, UINT32 DstFormat, UINT32 width, cons
 			{
 				const BYTE alpha = 0xFF;
 
-				for (x = 0; x < width; x++)
+				for (UINT32 x = 0; x < width; x++)
 				{
 					UINT32 color =
 					    FreeRDPGetColor(DstFormat, *(*ppR)++, *(*ppG)++, *(*ppB)++, alpha);
@@ -591,8 +589,9 @@ static INLINE BOOL planar_decompress_planes_raw(const BYTE* pSrcData[4], BYTE* p
                                                 UINT32 nYDst, UINT32 nWidth, UINT32 nHeight,
                                                 BOOL vFlip, UINT32 totalHeight)
 {
-	INT32 y;
-	INT32 beg, end, inc;
+	INT32 beg = 0;
+	INT32 end = 0;
+	INT32 inc = 0;
 	const BYTE* pR = pSrcData[0];
 	const BYTE* pG = pSrcData[1];
 	const BYTE* pB = pSrcData[2];
@@ -630,9 +629,9 @@ static INLINE BOOL planar_decompress_planes_raw(const BYTE* pSrcData[4], BYTE* p
 		return FALSE;
 	}
 
-	for (y = beg; y != end; y += inc)
+	for (INT32 y = beg; y != end; y += inc)
 	{
-		BYTE* pRGB;
+		BYTE* pRGB = NULL;
 
 		if (y > (INT64)nHeight)
 		{
@@ -655,7 +654,6 @@ static BOOL planar_subsample_expand(const BYTE* plane, size_t planeLength, UINT3
                                     BYTE* deltaPlane)
 {
 	size_t pos = 0;
-	UINT32 y;
 	WINPR_UNUSED(planeLength);
 
 	WINPR_ASSERT(plane);
@@ -675,12 +673,11 @@ static BOOL planar_subsample_expand(const BYTE* plane, size_t planeLength, UINT3
 		return FALSE;
 	}
 
-	for (y = 0; y < nHeight; y++)
+	for (UINT32 y = 0; y < nHeight; y++)
 	{
 		const BYTE* src = plane + y / 2 * nPlaneWidth;
-		UINT32 x;
 
-		for (x = 0; x < nWidth; x++)
+		for (UINT32 x = 0; x < nWidth; x++)
 		{
 			deltaPlane[pos++] = src[x / 2];
 		}
@@ -694,22 +691,22 @@ BOOL planar_decompress(BITMAP_PLANAR_CONTEXT* planar, const BYTE* pSrcData, UINT
                        UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst, UINT32 nDstWidth,
                        UINT32 nDstHeight, BOOL vFlip)
 {
-	BOOL cs;
-	BOOL rle;
-	UINT32 cll;
-	BOOL alpha;
+	BOOL cs = 0;
+	BOOL rle = 0;
+	UINT32 cll = 0;
+	BOOL alpha = 0;
 	BOOL useAlpha = FALSE;
-	INT32 status;
-	const BYTE* srcp;
-	UINT32 subSize;
-	UINT32 subWidth;
-	UINT32 subHeight;
-	UINT32 planeSize;
+	INT32 status = 0;
+	const BYTE* srcp = NULL;
+	UINT32 subSize = 0;
+	UINT32 subWidth = 0;
+	UINT32 subHeight = 0;
+	UINT32 planeSize = 0;
 	INT32 rleSizes[4] = { 0, 0, 0, 0 };
 	UINT32 rawSizes[4];
 	UINT32 rawWidths[4];
 	UINT32 rawHeights[4];
-	BYTE FormatHeader;
+	BYTE FormatHeader = 0;
 	const BYTE* planes[4] = { 0 };
 	const UINT32 w = MIN(nSrcWidth, nDstWidth);
 	const UINT32 h = MIN(nSrcHeight, nDstHeight);
@@ -878,7 +875,7 @@ BOOL planar_decompress(BITMAP_PLANAR_CONTEXT* planar, const BYTE* pSrcData, UINT
 
 	if (!cll) /* RGB */
 	{
-		UINT32 TempFormat;
+		UINT32 TempFormat = 0;
 		BYTE* pTempData = pDstData;
 		UINT32 nTempStep = nDstStep;
 		UINT32 nTotalHeight = nYDst + nDstHeight;
@@ -965,7 +962,7 @@ BOOL planar_decompress(BITMAP_PLANAR_CONTEXT* planar, const BYTE* pSrcData, UINT
 	}
 	else /* YCoCg */
 	{
-		UINT32 TempFormat;
+		UINT32 TempFormat = 0;
 		BYTE* pTempData = planar->pTempData;
 		UINT32 nTempStep = planar->nTempStep;
 		UINT32 nTotalHeight = planar->maxHeight;
@@ -1095,12 +1092,12 @@ static INLINE BOOL freerdp_split_color_planes(BITMAP_PLANAR_CONTEXT* planar, con
 
 	if (planar->topdown)
 	{
-		UINT32 i, j, k = 0;
-		for (i = 0; i < height; i++)
+		UINT32 k = 0;
+		for (UINT32 i = 0; i < height; i++)
 		{
 			const BYTE* pixel = &data[scanline * (UINT32)i];
 
-			for (j = 0; j < width; j++)
+			for (UINT32 j = 0; j < width; j++)
 			{
 				const UINT32 color = FreeRDPReadColor(pixel, format);
 				pixel += FreeRDPGetBytesPerPixel(format);
@@ -1112,14 +1109,13 @@ static INLINE BOOL freerdp_split_color_planes(BITMAP_PLANAR_CONTEXT* planar, con
 	}
 	else
 	{
-		INT64 i;
-		UINT32 j, k = 0;
+		UINT32 k = 0;
 
-		for (i = (INT64)height - 1; i >= 0; i--)
+		for (INT64 i = (INT64)height - 1; i >= 0; i--)
 		{
 			const BYTE* pixel = &data[scanline * (UINT32)i];
 
-			for (j = 0; j < width; j++)
+			for (UINT32 j = 0; j < width; j++)
 			{
 				const UINT32 color = FreeRDPReadColor(pixel, format);
 				pixel += FreeRDPGetBytesPerPixel(format);
@@ -1136,10 +1132,10 @@ static INLINE UINT32 freerdp_bitmap_planar_write_rle_bytes(const BYTE* pInBuffer
                                                            UINT32 nRunLength, BYTE* pOutBuffer,
                                                            UINT32 outBufferSize)
 {
-	const BYTE* pInput;
-	BYTE* pOutput;
-	BYTE controlByte;
-	UINT32 nBytesToWrite;
+	const BYTE* pInput = NULL;
+	BYTE* pOutput = NULL;
+	BYTE controlByte = 0;
+	UINT32 nBytesToWrite = 0;
 	pInput = pInBuffer;
 	pOutput = pOutBuffer;
 
@@ -1250,15 +1246,15 @@ static INLINE UINT32 freerdp_bitmap_planar_encode_rle_bytes(const BYTE* pInBuffe
                                                             UINT32 inBufferSize, BYTE* pOutBuffer,
                                                             UINT32 outBufferSize)
 {
-	BYTE symbol;
-	const BYTE* pInput;
-	BYTE* pOutput;
-	const BYTE* pBytes;
-	UINT32 cRawBytes;
-	UINT32 nRunLength;
-	UINT32 bSymbolMatch;
-	UINT32 nBytesWritten;
-	UINT32 nTotalBytesWritten;
+	BYTE symbol = 0;
+	const BYTE* pInput = NULL;
+	BYTE* pOutput = NULL;
+	const BYTE* pBytes = NULL;
+	UINT32 cRawBytes = 0;
+	UINT32 nRunLength = 0;
+	UINT32 bSymbolMatch = 0;
+	UINT32 nBytesWritten = 0;
+	UINT32 nTotalBytesWritten = 0;
 	symbol = 0;
 	cRawBytes = 0;
 	nRunLength = 0;
@@ -1328,12 +1324,12 @@ static INLINE UINT32 freerdp_bitmap_planar_encode_rle_bytes(const BYTE* pInBuffe
 BOOL freerdp_bitmap_planar_compress_plane_rle(const BYTE* inPlane, UINT32 width, UINT32 height,
                                               BYTE* outPlane, UINT32* dstSize)
 {
-	UINT32 index;
-	const BYTE* pInput;
-	BYTE* pOutput;
-	UINT32 outBufferSize;
-	UINT32 nBytesWritten;
-	UINT32 nTotalBytesWritten;
+	UINT32 index = 0;
+	const BYTE* pInput = NULL;
+	BYTE* pOutput = NULL;
+	UINT32 outBufferSize = 0;
+	UINT32 nBytesWritten = 0;
+	UINT32 nTotalBytesWritten = 0;
 
 	if (!outPlane)
 		return FALSE;
@@ -1420,10 +1416,10 @@ static INLINE BOOL freerdp_bitmap_planar_compress_planes_rle(BYTE* inPlanes[4],
 BYTE* freerdp_bitmap_planar_delta_encode_plane(const BYTE* inPlane, UINT32 width, UINT32 height,
                                                BYTE* outPlane)
 {
-	char s2c;
-	UINT32 y, x;
-	BYTE* outPtr;
-	const BYTE *srcPtr, *prevLinePtr;
+	char s2c = 0;
+	BYTE* outPtr = NULL;
+	const BYTE* srcPtr = NULL;
+	const BYTE* prevLinePtr = NULL;
 
 	if (!outPlane)
 	{
@@ -1440,9 +1436,9 @@ BYTE* freerdp_bitmap_planar_delta_encode_plane(const BYTE* inPlane, UINT32 width
 	srcPtr = inPlane + width;
 	prevLinePtr = inPlane;
 
-	for (y = 1; y < height; y++)
+	for (UINT32 y = 1; y < height; y++)
 	{
-		for (x = 0; x < width; x++, outPtr++, srcPtr++, prevLinePtr++)
+		for (UINT32 x = 0; x < width; x++, outPtr++, srcPtr++, prevLinePtr++)
 		{
 			INT32 delta = *srcPtr - *prevLinePtr;
 			s2c = (delta >= 0) ? (char)delta : (char)(~((BYTE)(-delta)) + 1);
@@ -1458,9 +1454,7 @@ BYTE* freerdp_bitmap_planar_delta_encode_plane(const BYTE* inPlane, UINT32 width
 static INLINE BOOL freerdp_bitmap_planar_delta_encode_planes(BYTE* inPlanes[4], UINT32 width,
                                                              UINT32 height, BYTE* outPlanes[4])
 {
-	UINT32 i;
-
-	for (i = 0; i < 4; i++)
+	for (UINT32 i = 0; i < 4; i++)
 	{
 		outPlanes[i] =
 		    freerdp_bitmap_planar_delta_encode_plane(inPlanes[i], width, height, outPlanes[i]);
@@ -1476,9 +1470,9 @@ BYTE* freerdp_bitmap_compress_planar(BITMAP_PLANAR_CONTEXT* context, const BYTE*
                                      UINT32 format, UINT32 width, UINT32 height, UINT32 scanline,
                                      BYTE* dstData, UINT32* pDstSize)
 {
-	UINT32 size;
-	BYTE* dstp;
-	UINT32 planeSize;
+	UINT32 size = 0;
+	BYTE* dstp = NULL;
+	UINT32 planeSize = 0;
 	UINT32 dstSizes[4] = { 0 };
 	BYTE FormatHeader = 0;
 
