@@ -505,6 +505,10 @@ static int aad_send_auth_request(rdpAad* aad, const char* ts_nonce)
 	if (stream_sprintf(s, "{\"rdp_assertion\":\"%s.%s.%s\"}", jws_header, jws_payload,
 	                   jws_signature) < 0)
 		goto fail;
+
+	/* Include null terminator in PDU */
+	Stream_Write_UINT8(s, 0);
+
 	Stream_SealLength(s);
 
 	if (transport_write(aad->transport, s) < 0)
@@ -671,7 +675,8 @@ BOOL generate_pop_key(rdpAad* aad)
 	BOOL ret = FALSE;
 	char* buffer = NULL;
 	char* b64_hash = NULL;
-	char *e = NULL, *n = NULL;
+	char* e = NULL;
+	char* n = NULL;
 
 	WINPR_ASSERT(aad);
 
@@ -800,7 +805,10 @@ rdpAad* aad_new(rdpContext* context, rdpTransport* transport)
 
 	return aad;
 fail:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	aad_free(aad);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
