@@ -100,8 +100,9 @@ struct s_http_response
 
 static char* string_strnstr(char* str1, const char* str2, size_t slen)
 {
-	char c, sc;
-	size_t len;
+	char c = 0;
+	char sc = 0;
+	size_t len = 0;
 
 	if ((c = *str2++) != '\0')
 	{
@@ -133,14 +134,6 @@ static BOOL strings_equals_nocase(const void* obj1, const void* obj2)
 	return _stricmp(obj1, obj2) == 0;
 }
 
-static void* copy_string(const void* ptr)
-{
-	const char* str = ptr;
-	if (!str)
-		return NULL;
-	return _strdup(ptr);
-}
-
 HttpContext* http_context_new(void)
 {
 	HttpContext* context = (HttpContext*)calloc(1, sizeof(HttpContext));
@@ -156,15 +149,18 @@ HttpContext* http_context_new(void)
 	if (!key || !value)
 		goto fail;
 
-	key->fnObjectFree = free;
-	key->fnObjectNew = copy_string;
-	value->fnObjectFree = free;
-	value->fnObjectNew = copy_string;
+	key->fnObjectFree = winpr_ObjectStringFree;
+	key->fnObjectNew = winpr_ObjectStringClone;
+	value->fnObjectFree = winpr_ObjectStringFree;
+	value->fnObjectNew = winpr_ObjectStringClone;
 
 	return context;
 
 fail:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	http_context_free(context);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
@@ -551,9 +547,10 @@ BOOL http_request_set_transfer_encoding(HttpRequest* request, TRANSFER_ENCODING
 WINPR_ATTR_FORMAT_ARG(2, 3)
 static BOOL http_encode_print(wStream* s, WINPR_FORMAT_ARG const char* fmt, ...)
 {
-	char* str;
+	char* str = NULL;
 	va_list ap;
-	int length, used;
+	int length = 0;
+	int used = 0;
 
 	if (!s || !fmt)
 		return FALSE;
@@ -652,7 +649,7 @@ unlock:
 
 wStream* http_request_write(HttpContext* context, HttpRequest* request)
 {
-	wStream* s;
+	wStream* s = NULL;
 
 	if (!context || !request)
 		return NULL;
@@ -785,8 +782,8 @@ static BOOL http_response_parse_header_status_line(HttpResponse* response, const
 {
 	BOOL rc = FALSE;
 	char* separator = NULL;
-	char* status_code;
-	char* reason_phrase;
+	char* status_code = NULL;
+	char* reason_phrase = NULL;
 
 	if (!response)
 		goto fail;
@@ -838,7 +835,7 @@ static BOOL http_response_parse_header_field(HttpResponse* response, const char*
 
 	if (_stricmp(name, "Content-Length") == 0)
 	{
-		unsigned long long val;
+		unsigned long long val = 0;
 		errno = 0;
 		val = _strtoui64(value, NULL, 0);
 
@@ -965,14 +962,12 @@ static BOOL http_response_parse_header_field(HttpResponse* response, const char*
 static BOOL http_response_parse_header(HttpResponse* response)
 {
 	BOOL rc = FALSE;
-	char c;
-	size_t count;
-	char* line;
-	char* name;
-	char* value;
-	char* colon_pos;
-	char* end_of_header;
-	char end_of_header_char;
+	char c = 0;
+	char* line = NULL;
+	char* name = NULL;
+	char* colon_pos = NULL;
+	char* end_of_header = NULL;
+	char end_of_header_char = 0;
 
 	if (!response)
 		goto fail;
@@ -983,7 +978,7 @@ static BOOL http_response_parse_header(HttpResponse* response)
 	if (!http_response_parse_header_status_line(response, response->lines[0]))
 		goto fail;
 
-	for (count = 1; count < response->count; count++)
+	for (size_t count = 1; count < response->count; count++)
 	{
 		line = response->lines[count];
 
@@ -1021,7 +1016,8 @@ static BOOL http_response_parse_header(HttpResponse* response)
 		name = line;
 
 		/* eat space and tabs before header value */
-		for (value = colon_pos + 1; *value; value++)
+		char* value = colon_pos + 1;
+		for (; *value; value++)
 		{
 			if ((*value != ' ') && (*value != '\t'))
 				break;
@@ -1113,7 +1109,7 @@ static int print_bio_error(const char* str, size_t len, void* bp)
 int http_chuncked_read(BIO* bio, BYTE* pBuffer, size_t size,
                        http_encoding_chunked_context* encodingContext)
 {
-	int status;
+	int status = 0;
 	int effectiveDataLen = 0;
 	WINPR_ASSERT(bio);
 	WINPR_ASSERT(pBuffer);
@@ -1218,7 +1214,7 @@ int http_chuncked_read(BIO* bio, BYTE* pBuffer, size_t size,
 
 HttpResponse* http_response_recv(rdpTls* tls, BOOL readContentLength)
 {
-	size_t position;
+	size_t position = 0;
 	size_t bodyLength = 0;
 	size_t payloadOffset = 0;
 	HttpResponse* response = http_response_new();
@@ -1230,8 +1226,8 @@ HttpResponse* http_response_recv(rdpTls* tls, BOOL readContentLength)
 
 	while (payloadOffset == 0)
 	{
-		size_t s;
-		char* end;
+		size_t s = 0;
+		char* end = NULL;
 		/* Read until we encounter \r\n\r\n */
 		ERR_clear_error();
 		int status = BIO_read(tls->bio, Stream_Pointer(response->data), 1);
@@ -1386,7 +1382,7 @@ HttpResponse* http_response_recv(rdpTls* tls, BOOL readContentLength)
 		{
 			while (response->BodyLength < bodyLength)
 			{
-				int status;
+				int status = 0;
 
 				if (!Stream_EnsureRemainingCapacity(response->data,
 				                                    bodyLength - response->BodyLength))
@@ -1502,7 +1498,10 @@ HttpResponse* http_response_new(void)
 	response->TransferEncoding = TransferEncodingIdentity;
 	return response;
 fail:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	http_response_free(response);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
