@@ -109,7 +109,7 @@ BOOL proxy_prepare(rdpSettings* settings, const char** lpPeerHostname, UINT16* l
 
 static BOOL value_to_int(const char* value, LONGLONG* result, LONGLONG min, LONGLONG max)
 {
-	long long rc;
+	long long rc = 0;
 
 	if (!value || !result)
 		return FALSE;
@@ -129,7 +129,9 @@ static BOOL value_to_int(const char* value, LONGLONG* result, LONGLONG min, LONG
 
 static BOOL cidr4_match(const struct in_addr* addr, const struct in_addr* net, BYTE bits)
 {
-	uint32_t mask, amask, nmask;
+	uint32_t mask = 0;
+	uint32_t amask = 0;
+	uint32_t nmask = 0;
 
 	if (bits == 0)
 		return TRUE;
@@ -145,7 +147,8 @@ static BOOL cidr6_match(const struct in6_addr* address, const struct in6_addr* n
 {
 	const uint32_t* a = (const uint32_t*)address;
 	const uint32_t* n = (const uint32_t*)network;
-	size_t bits_whole, bits_incomplete;
+	size_t bits_whole = 0;
+	size_t bits_incomplete = 0;
 	bits_whole = bits >> 5;
 	bits_incomplete = bits & 0x1F;
 
@@ -170,10 +173,10 @@ static BOOL check_no_proxy(rdpSettings* settings, const char* no_proxy)
 {
 	const char* delimiter = ",";
 	BOOL result = FALSE;
-	char* current;
-	char* copy;
+	char* current = NULL;
+	char* copy = NULL;
 	char* context = NULL;
-	size_t host_len;
+	size_t host_len = 0;
 	struct sockaddr_in sa4;
 	struct sockaddr_in6 sa6;
 	BOOL is_ipv4 = FALSE;
@@ -281,8 +284,8 @@ static BOOL check_no_proxy(rdpSettings* settings, const char* no_proxy)
 
 void proxy_read_environment(rdpSettings* settings, char* envname)
 {
-	DWORD envlen;
-	char* env;
+	DWORD envlen = 0;
+	char* env = NULL;
 	envlen = GetEnvironmentVariableA(envname, NULL, 0);
 
 	if (!envlen)
@@ -325,9 +328,9 @@ BOOL proxy_parse_uri(rdpSettings* settings, const char* uri_in)
 {
 	BOOL rc = FALSE;
 	const char* protocol = "";
-	UINT16 port;
-	char* p;
-	char* atPtr;
+	UINT16 port = 0;
+	char* p = NULL;
+	char* atPtr = NULL;
 	char* uri_copy = _strdup(uri_in);
 	char* uri = uri_copy;
 	if (!uri)
@@ -414,7 +417,7 @@ BOOL proxy_parse_uri(rdpSettings* settings, const char* uri_in)
 
 	if (p)
 	{
-		LONGLONG val;
+		LONGLONG val = 0;
 
 		if (!value_to_int(&p[1], &val, 0, UINT16_MAX))
 		{
@@ -518,15 +521,15 @@ static BOOL http_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
                                const char* proxyPassword, const char* hostname, UINT16 port)
 {
 	BOOL rc = FALSE;
-	int status;
-	wStream* s;
+	int status = 0;
+	wStream* s = NULL;
 	char port_str[10] = { 0 };
 	char recv_buf[256] = { 0 };
 	char* eol = NULL;
 	size_t resultsize = 0;
-	size_t reserveSize;
-	size_t portLen;
-	size_t hostLen;
+	size_t reserveSize = 0;
+	size_t portLen = 0;
+	size_t hostLen = 0;
 	const char connect[] = "CONNECT ";
 	const char httpheader[] = " HTTP/1.1" CRLF "Host: ";
 
@@ -564,7 +567,7 @@ static BOOL http_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
 			else
 			{
 				const char basic[] = CRLF "Proxy-Authorization: Basic ";
-				char* base64;
+				char* base64 = NULL;
 
 				sprintf_s(creds, size, "%s:%s", proxyUsername, proxyPassword);
 				base64 = crypto_base64_encode((const BYTE*)creds, size - 1);
@@ -661,7 +664,7 @@ fail:
 
 static int recv_socks_reply(BIO* bufferedBio, BYTE* buf, int len, char* reason, BYTE checkVer)
 {
-	int status;
+	int status = 0;
 
 	for (;;)
 	{
@@ -711,8 +714,9 @@ static int recv_socks_reply(BIO* bufferedBio, BYTE* buf, int len, char* reason,
 static BOOL socks_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
                                 const char* proxyPassword, const char* hostname, UINT16 port)
 {
-	int status;
-	int nauthMethods = 1, writeLen = 3;
+	int status = 0;
+	int nauthMethods = 1;
+	int writeLen = 3;
 	BYTE buf[3 + 255 + 255]; /* biggest packet is user/pass auth */
 	size_t hostnlen = strnlen(hostname, 255);
 
@@ -757,7 +761,7 @@ static BOOL socks_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
 			{
 				int usernameLen = strnlen(proxyUsername, 255);
 				int userpassLen = strnlen(proxyPassword, 255);
-				BYTE* ptr;
+				BYTE* ptr = NULL;
 
 				if (nauthMethods < 2)
 				{
