@@ -632,9 +632,6 @@ static BOOL certificate_process_server_public_signature(rdpCertificate* certific
                                                         wStream* s, UINT32 siglen)
 {
 	WINPR_ASSERT(certificate);
-#if defined(CERT_VALIDATE_PADDING) || defined(CERT_VALIDATE_RSA)
-	size_t i, sum;
-#endif
 #if defined(CERT_VALIDATE_RSA)
 	BYTE sig[TSSK_KEY_LENGTH];
 #endif
@@ -666,16 +663,17 @@ static BOOL certificate_process_server_public_signature(rdpCertificate* certific
 
 		/* Last 8 bytes shall be all zero. */
 #if defined(CERT_VALIDATE_PADDING)
-
-	for (sum = 0, i = sizeof(encsig) - 8; i < sizeof(encsig); i++)
-		sum += encsig[i];
-
-	if (sum != 0)
 	{
-		WLog_ERR(TAG, "invalid signature");
-		return FALSE;
-	}
+		size_t sum = 0;
+		for (size_t i = sizeof(encsig) - 8; i < sizeof(encsig); i++)
+			sum += encsig[i];
 
+		if (sum != 0)
+		{
+			WLog_ERR(TAG, "invalid signature");
+			return FALSE;
+		}
+	}
 #endif
 #if defined(CERT_VALIDATE_RSA)
 
@@ -703,16 +701,17 @@ static BOOL certificate_process_server_public_signature(rdpCertificate* certific
 	 * The 18th through 62nd bytes are each 0xFF.
 	 * The 63rd byte is 0x01.
 	 */
-
-	for (sum = 0, i = 17; i < 62; i++)
-		sum += sig[i];
-
-	if (sig[16] != 0x00 || sum != 0xFF * (62 - 17) || sig[62] != 0x01)
 	{
-		WLog_ERR(TAG, "invalid signature");
-		return FALSE;
-	}
+		size_t sum = 0;
+		for (size_t i = 17; i < 62; i++)
+			sum += sig[i];
 
+		if (sig[16] != 0x00 || sum != 0xFF * (62 - 17) || sig[62] != 0x01)
+		{
+			WLog_ERR(TAG, "invalid signature");
+			return FALSE;
+		}
+	}
 #endif
 	return TRUE;
 }
@@ -1003,7 +1002,8 @@ BOOL freerdp_certificate_read_server_cert(rdpCertificate* certificate, const BYT
                                           size_t length)
 {
 	BOOL ret = FALSE;
-	wStream *s, sbuffer;
+	wStream* s = NULL;
+	wStream sbuffer;
 	UINT32 dwVersion = 0;
 
 	WINPR_ASSERT(certificate);
@@ -1334,9 +1334,9 @@ char* freerdp_certificate_get_fingerprint_by_hash_ex(const rdpCertificate* cert,
 	pos = 0;
 
 	size_t i = 0;
-	for (i = 0; i < (fp_len - 1); i++)
+	for (; i < (fp_len - 1); i++)
 	{
-		int rc;
+		int rc = 0;
 		char* p = &fp_buffer[pos];
 		if (separator)
 			rc = sprintf_s(p, size - pos, "%02" PRIx8 ":", fp[i]);
@@ -1409,8 +1409,8 @@ char* freerdp_certificate_get_pem(const rdpCertificate* cert, size_t* pLength)
 	if (!cert->x509)
 		return NULL;
 
-	BIO* bio;
-	int status;
+	BIO* bio = NULL;
+	int status = 0;
 
 	/**
 	 * Don't manage certificates internally, leave it up entirely to the external client
@@ -1435,8 +1435,8 @@ char* freerdp_certificate_get_pem(const rdpCertificate* cert, size_t* pLength)
 #if 0
         if (chain)
         {
-            count = sk_X509_num(chain);
-            for (x = 0; x < count; x++)
+            int count = sk_X509_num(chain);
+            for (int x = 0; x < count; x++)
             {
                 X509* c = sk_X509_value(chain, x);
                 status = PEM_write_bio_X509(bio, c);
@@ -1490,7 +1490,7 @@ BOOL freerdp_certificate_get_public_key(const rdpCertificate* cert, BYTE** Publi
 {
 	BYTE* ptr = NULL;
 	BYTE* optr = NULL;
-	int length;
+	int length = 0;
 	BOOL status = FALSE;
 	EVP_PKEY* pkey = NULL;
 
