@@ -115,8 +115,8 @@ static void free_tls_bindings(rdpTls* tls)
 
 static int bio_rdp_tls_write(BIO* bio, const char* buf, int size)
 {
-	int error;
-	int status;
+	int error = 0;
+	int status = 0;
 	BIO_RDP_TLS* tls = (BIO_RDP_TLS*)BIO_get_data(bio);
 
 	if (!buf || !tls)
@@ -169,8 +169,8 @@ static int bio_rdp_tls_write(BIO* bio, const char* buf, int size)
 
 static int bio_rdp_tls_read(BIO* bio, char* buf, int size)
 {
-	int error;
-	int status;
+	int error = 0;
+	int status = 0;
 	BIO_RDP_TLS* tls = (BIO_RDP_TLS*)BIO_get_data(bio);
 
 	if (!buf || !tls)
@@ -240,8 +240,8 @@ static int bio_rdp_tls_read(BIO* bio, char* buf, int size)
 
 static int bio_rdp_tls_puts(BIO* bio, const char* str)
 {
-	size_t size;
-	int status;
+	size_t size = 0;
+	int status = 0;
 
 	if (!str)
 		return 0;
@@ -259,9 +259,9 @@ static int bio_rdp_tls_gets(BIO* bio, char* str, int size)
 
 static long bio_rdp_tls_ctrl(BIO* bio, int cmd, long num, void* ptr)
 {
-	BIO* ssl_rbio;
-	BIO* ssl_wbio;
-	BIO* next_bio;
+	BIO* ssl_rbio = NULL;
+	BIO* ssl_wbio = NULL;
+	BIO* next_bio = NULL;
 	int status = -1;
 	BIO_RDP_TLS* tls = (BIO_RDP_TLS*)BIO_get_data(bio);
 
@@ -472,7 +472,7 @@ static long bio_rdp_tls_ctrl(BIO* bio, int cmd, long num, void* ptr)
 
 static int bio_rdp_tls_new(BIO* bio)
 {
-	BIO_RDP_TLS* tls;
+	BIO_RDP_TLS* tls = NULL;
 	BIO_set_flags(bio, BIO_FLAGS_SHOULD_RETRY);
 
 	if (!(tls = calloc(1, sizeof(BIO_RDP_TLS))))
@@ -485,7 +485,7 @@ static int bio_rdp_tls_new(BIO* bio)
 
 static int bio_rdp_tls_free(BIO* bio)
 {
-	BIO_RDP_TLS* tls;
+	BIO_RDP_TLS* tls = NULL;
 
 	if (!bio)
 		return 0;
@@ -517,7 +517,7 @@ static int bio_rdp_tls_free(BIO* bio)
 static long bio_rdp_tls_callback_ctrl(BIO* bio, int cmd, bio_info_cb* fp)
 {
 	long status = 0;
-	BIO_RDP_TLS* tls;
+	BIO_RDP_TLS* tls = NULL;
 
 	if (!bio)
 		return 0;
@@ -575,8 +575,8 @@ static BIO_METHOD* BIO_s_rdp_tls(void)
 
 static BIO* BIO_new_rdp_tls(SSL_CTX* ctx, int client)
 {
-	BIO* bio;
-	SSL* ssl;
+	BIO* bio = NULL;
+	SSL* ssl = NULL;
 	bio = BIO_new(BIO_s_rdp_tls());
 
 	if (!bio)
@@ -601,7 +601,7 @@ static BIO* BIO_new_rdp_tls(SSL_CTX* ctx, int client)
 
 static rdpCertificate* tls_get_certificate(rdpTls* tls, BOOL peer)
 {
-	X509* remote_cert;
+	X509* remote_cert = NULL;
 
 	if (peer)
 		remote_cert = SSL_get_peer_certificate(tls->ssl);
@@ -642,7 +642,7 @@ static SecPkgContext_Bindings* tls_get_channel_bindings(const rdpCertificate* ce
 
 	/* See https://www.rfc-editor.org/rfc/rfc5929 for details about hashes */
 	WINPR_MD_TYPE alg = freerdp_certificate_get_signature_alg(cert);
-	const char* hash;
+	const char* hash = NULL;
 	switch (alg)
 	{
 
@@ -699,7 +699,7 @@ static BOOL CALLBACK secrets_file_init_cb(PINIT_ONCE once, PVOID param, PVOID* c
 
 static void SSLCTX_keylog_cb(const SSL* ssl, const char* line)
 {
-	char* dfile;
+	char* dfile = NULL;
 
 	if (secrets_file_idx == -1)
 		return;
@@ -912,7 +912,7 @@ TlsHandshakeResult freerdp_tls_handshake(rdpTls* tls)
 		return TLS_HANDSHAKE_CONTINUE;
 	}
 
-	int verify_status;
+	int verify_status = 0;
 	rdpCertificate* cert = tls_get_certificate(tls, tls->isClientMode);
 
 	if (!cert)
@@ -965,8 +965,8 @@ static int pollAndHandshake(rdpTls* tls)
 
 	do
 	{
-		HANDLE event;
-		DWORD status;
+		HANDLE event = NULL;
+		DWORD status = 0;
 		if (BIO_get_event(tls->bio, &event) < 0)
 		{
 			WLog_ERR(TAG, "unable to retrieve BIO associated event");
@@ -1065,7 +1065,7 @@ TlsHandshakeResult freerdp_tls_accept_ex(rdpTls* tls, BIO* underlying, rdpSettin
 	WINPR_ASSERT(tls);
 
 	long options = 0;
-	int status;
+	int status = 0;
 
 	/**
 	 * SSL_OP_NO_SSLv2:
@@ -1216,7 +1216,7 @@ BOOL freerdp_tls_send_alert(rdpTls* tls)
 int freerdp_tls_write_all(rdpTls* tls, const BYTE* data, int length)
 {
 	WINPR_ASSERT(tls);
-	int status;
+	int status = 0;
 	int offset = 0;
 	BIO* bio = tls->bio;
 
@@ -1293,8 +1293,8 @@ static BOOL is_redirected(rdpTls* tls)
 static BOOL is_accepted(rdpTls* tls, const BYTE* pem, size_t length)
 {
 	rdpSettings* settings = tls->settings;
-	char* AccpetedKey;
-	UINT32 AcceptedKeyLength;
+	char* AccpetedKey = NULL;
+	UINT32 AcceptedKeyLength = 0;
 
 	if (tls->isGatewayTransport)
 	{
@@ -1346,8 +1346,8 @@ static BOOL is_accepted(rdpTls* tls, const BYTE* pem, size_t length)
 static BOOL compare_fingerprint(const char* fp, const char* hash, const rdpCertificate* cert,
                                 BOOL separator)
 {
-	BOOL equal;
-	char* strhash;
+	BOOL equal = 0;
+	char* strhash = NULL;
 
 	WINPR_ASSERT(fp);
 	WINPR_ASSERT(hash);
@@ -1389,7 +1389,7 @@ static BOOL is_accepted_fingerprint(const rdpCertificate* cert,
 		{
 			char* subcontext = NULL;
 			const char* h = strtok_s(cur, ":", &subcontext);
-			const char* fp;
+			const char* fp = NULL;
 
 			if (!h)
 				goto next;
@@ -1448,9 +1448,9 @@ static BOOL tls_extract_pem(const rdpCertificate* cert, BYTE** PublicKey, size_t
 int tls_verify_certificate(rdpTls* tls, const rdpCertificate* cert, const char* hostname,
                            UINT16 port)
 {
-	int match;
-	size_t length;
-	BOOL certificate_status;
+	int match = 0;
+	size_t length = 0;
+	BOOL certificate_status = 0;
 	char* common_name = NULL;
 	size_t common_name_length = 0;
 	char** dns_names = 0;
@@ -1461,7 +1461,7 @@ int tls_verify_certificate(rdpTls* tls, const rdpCertificate* cert, const char*
 	rdpCertificateData* certificate_data = NULL;
 	BYTE* pemCert = NULL;
 	DWORD flags = VERIFY_CERT_FLAG_NONE;
-	freerdp* instance;
+	freerdp* instance = NULL;
 
 	WINPR_ASSERT(tls);
 	WINPR_ASSERT(tls->settings);
@@ -1697,7 +1697,7 @@ int tls_verify_certificate(rdpTls* tls, const rdpCertificate* cert, const char*
 					const BOOL fpIsAllocated =
 					    !old_pem || !freerdp_settings_get_bool(
 					                    tls->settings, FreeRDP_CertificateCallbackPreferPEM);
-					char* fp;
+					char* fp = NULL;
 					if (!fpIsAllocated)
 					{
 						cflags |= VERIFY_CERT_FLAG_FP_IS_PEM;
@@ -1846,7 +1846,7 @@ void tls_print_certificate_name_mismatch_error(const char* hostname, UINT16 port
 
 rdpTls* freerdp_tls_new(rdpSettings* settings)
 {
-	rdpTls* tls;
+	rdpTls* tls = NULL;
 	tls = (rdpTls*)calloc(1, sizeof(rdpTls));
 
 	if (!tls)
