@@ -32,6 +32,7 @@
 #include <winpr/file.h>
 #include <winpr/string.h>
 #include <winpr/path.h>
+#include <winpr/image.h>
 #include <winpr/winsock.h>
 
 #include <freerdp/streamdump.h>
@@ -77,6 +78,7 @@ static void test_peer_context_free(freerdp_peer* client, rdpContext* ctx)
 
 	if (context)
 	{
+		winpr_image_free(context->image, TRUE);
 		if (context->debug_channel_thread)
 		{
 			WINPR_ASSERT(context->stopEvent);
@@ -86,7 +88,6 @@ static void test_peer_context_free(freerdp_peer* client, rdpContext* ctx)
 		}
 
 		Stream_Free(context->s, TRUE);
-		free(context->icon_data);
 		free(context->bg_data);
 		rfx_context_free(context->rfx_context);
 		nsc_context_free(context->nsc_context);
@@ -115,6 +116,9 @@ static BOOL test_peer_context_new(freerdp_peer* client, rdpContext* ctx)
 	WINPR_ASSERT(context);
 	WINPR_ASSERT(ctx->settings);
 
+	context->image = winpr_image_new();
+	if (!context->image)
+		goto fail;
 	if (!(context->rfx_context = rfx_context_new_ex(
 	          TRUE, freerdp_settings_get_uint32(ctx->settings, FreeRDP_ThreadingFlags))))
 		goto fail;
@@ -124,14 +128,10 @@ static BOOL test_peer_context_new(freerdp_peer* client, rdpContext* ctx)
 		goto fail;
 
 	rfx_context_set_mode(context->rfx_context, RLGR3);
-	rfx_context_set_pixel_format(context->rfx_context, PIXEL_FORMAT_RGB24);
 
 	if (!(context->nsc_context = nsc_context_new()))
 		goto fail;
 
-	if (!nsc_context_set_parameters(context->nsc_context, NSC_COLOR_FORMAT, PIXEL_FORMAT_RGB24))
-		goto fail;
-
 	if (!(context->s = Stream_New(NULL, 65536)))
 		goto fail;
 
@@ -170,9 +170,9 @@ static wStream* test_peer_stream_init(testPeerContext* context)
 
 static void test_peer_begin_frame(freerdp_peer* client)
 {
-	rdpUpdate* update;
+	rdpUpdate* update = NULL;
 	SURFACE_FRAME_MARKER fm = { 0 };
-	testPeerContext* context;
+	testPeerContext* context = NULL;
 
 	WINPR_ASSERT(client);
 	WINPR_ASSERT(client->context);
@@ -191,9 +191,9 @@ static void test_peer_begin_frame(freerdp_peer* client)
 
 static void test_peer_end_frame(freerdp_peer* client)
 {
-	rdpUpdate* update;
+	rdpUpdate* update = NULL;
 	SURFACE_FRAME_MARKER fm = { 0 };
-	testPeerContext* context;
+	testPeerContext* context = NULL;
 
 	WINPR_ASSERT(client);
 
@@ -212,15 +212,17 @@ static void test_peer_end_frame(freerdp_peer* client)
 
 static BOOL test_peer_draw_background(freerdp_peer* client)
 {
-	size_t size;
-	wStream* s;
+	size_t size = 0;
+	wStream* s = NULL;
 	RFX_RECT rect;
-	BYTE* rgb_data;
-	const rdpSettings* settings;
-	rdpUpdate* update;
+	BYTE* rgb_data = NULL;
+	const rdpSettings* settings = NULL;
+	rdpUpdate* update = NULL;
 	SURFACE_BITS_COMMAND cmd = { 0 };
-	testPeerContext* context;
+	testPeerContext* context = NULL;
 	BOOL ret = FALSE;
+	const UINT32 colorFormat = PIXEL_FORMAT_RGB24;
+	const size_t bpp = FreeRDPGetBytesPerPixel(colorFormat);
 
 	WINPR_ASSERT(client);
 	context = (testPeerContext*)client->context;
@@ -244,7 +246,7 @@ static BOOL test_peer_draw_background(freerdp_peer* client)
 	rect.y = 0;
 	rect.width = (UINT16)freerdp_settings_get_uint32(settings, FreeRDP_DesktopWidth);
 	rect.height = (UINT16)freerdp_settings_get_uint32(settings, FreeRDP_DesktopHeight);
-	size = rect.width * rect.height * 3ULL;
+	size = bpp * rect.width * rect.height;
 
 	if (!(rgb_data = malloc(size)))
 	{
@@ -257,8 +259,9 @@ static BOOL test_peer_draw_background(freerdp_peer* client)
 	if (RemoteFxCodec)
 	{
 		WLog_DBG(TAG, "Using RemoteFX codec");
+		rfx_context_set_pixel_format(context->rfx_context, colorFormat);
 		if (!rfx_compose_message(context->rfx_context, s, &rect, 1, rgb_data, rect.width,
-		                         rect.height, rect.width * 3))
+		                         rect.height, rect.width * bpp))
 		{
 			goto out;
 		}
@@ -272,8 +275,9 @@ static BOOL test_peer_draw_background(freerdp_peer* client)
 	else
 	{
 		WLog_DBG(TAG, "Using NSCodec");
+		nsc_context_set_parameters(context->nsc_context, NSC_COLOR_FORMAT, colorFormat);
 		nsc_compose_message(context->nsc_context, s, rgb_data, rect.width, rect.height,
-		                    rect.width * 3ULL);
+		                    rect.width * bpp);
 		const UINT32 NSCodecId = freerdp_settings_get_uint32(settings, FreeRDP_NSCodecId);
 		WINPR_ASSERT(NSCodecId <= UINT16_MAX);
 		cmd.bmp.codecID = (UINT16)NSCodecId;
@@ -300,15 +304,35 @@ out:
 	return ret;
 }
 
+static int open_icon(wImage* img)
+{
+	char* paths[] = { SAMPLE_RESOURCE_ROOT, "." };
+	const char* names[] = { "test_icon.webp", "test_icon.png", "test_icon.jpg", "test_icon.bmp" };
+
+	for (size_t x = 0; x < ARRAYSIZE(paths); x++)
+	{
+		const char* path = paths[x];
+		if (!winpr_PathFileExists(path))
+			continue;
+
+		for (size_t y = 0; y < ARRAYSIZE(names); y++)
+		{
+			const char* name = names[y];
+			char* file = GetCombinedPath(path, name);
+			int rc = winpr_image_read(img, file);
+			free(file);
+			if (rc > 0)
+				return rc;
+		}
+	}
+	WLog_ERR(TAG, "Unable to open test icon");
+	return -1;
+}
+
 static BOOL test_peer_load_icon(freerdp_peer* client)
 {
-	testPeerContext* context;
-	FILE* fp = NULL;
-	int i;
-	char line[50] = { 0 };
-	BYTE* rgb_data = NULL;
-	int c;
-	rdpSettings* settings;
+	testPeerContext* context = NULL;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(client);
 
@@ -325,73 +349,29 @@ static BOOL test_peer_load_icon(freerdp_peer* client)
 		return FALSE;
 	}
 
-	if ((fp = winpr_fopen("test_icon.ppm", "r")) == NULL)
-	{
-		WLog_ERR(TAG, "Unable to open test icon");
-		return FALSE;
-	}
-
-	/* P3 */
-	char* s = fgets(line, sizeof(line), fp);
-	if (!s)
+	int rc = open_icon(context->image);
+	if (rc <= 0)
 		goto out_fail;
 
-	/* Creater comment */
-	s = fgets(line, sizeof(line), fp);
-	if (!s)
-		goto out_fail;
-
-	/* width height */
-	s = fgets(line, sizeof(line), fp);
-	if (!s)
-		goto out_fail;
-
-	if (sscanf(line, "%hu %hu", &context->icon_width, &context->icon_height) < 2)
-	{
-		WLog_ERR(TAG, "Problem while extracting width/height from the icon file");
-		goto out_fail;
-	}
-
-	/* Max */
-	s = fgets(line, sizeof(line), fp);
-	if (!s)
-		goto out_fail;
-
-	if (!(rgb_data = calloc(context->icon_height, context->icon_width * 3)))
-		goto out_fail;
-
-	for (i = 0; i < context->icon_width * context->icon_height * 3; i++)
-	{
-		if (!fgets(line, sizeof(line), fp) || (sscanf(line, "%d", &c) != 1))
-			goto out_fail;
-
-		rgb_data[i] = (BYTE)c;
-	}
-
 	/* background with same size, which will be used to erase the icon from old position */
-	if (!(context->bg_data = calloc(context->icon_height, context->icon_width * 3)))
+	if (!(context->bg_data = calloc(context->image->height, context->image->width * 3)))
 		goto out_fail;
 
-	memset(context->bg_data, 0xA0, context->icon_width * context->icon_height * 3ull);
-	context->icon_data = rgb_data;
-	fclose(fp);
+	memset(context->bg_data, 0xA0, context->image->height * context->image->width * 3ull);
 	return TRUE;
 out_fail:
-	free(rgb_data);
 	context->bg_data = NULL;
-	if (fp)
-		fclose(fp);
 	return FALSE;
 }
 
 static void test_peer_draw_icon(freerdp_peer* client, UINT32 x, UINT32 y)
 {
-	wStream* s;
+	wStream* s = NULL;
 	RFX_RECT rect;
-	rdpUpdate* update;
-	rdpSettings* settings;
+	rdpUpdate* update = NULL;
+	rdpSettings* settings = NULL;
 	SURFACE_BITS_COMMAND cmd = { 0 };
-	testPeerContext* context;
+	testPeerContext* context = NULL;
 
 	WINPR_ASSERT(client);
 
@@ -407,15 +387,26 @@ static void test_peer_draw_icon(freerdp_peer* client, UINT32 x, UINT32 y)
 	if (freerdp_settings_get_bool(settings, FreeRDP_DumpRemoteFx))
 		return;
 
-	if (context->icon_width < 1 || !context->activated)
+	if (context->image->width < 1 || !context->activated)
+		return;
+
+	rect.x = 0;
+	rect.y = 0;
+	rect.width = context->image->width;
+	rect.height = context->image->height;
+
+	const UINT32 w = freerdp_settings_get_uint32(settings, FreeRDP_DesktopWidth);
+	const UINT32 h = freerdp_settings_get_uint32(settings, FreeRDP_DesktopHeight);
+	if (context->icon_x + context->image->width > w)
+		return;
+	if (context->icon_y + context->image->height > h)
+		return;
+	if (x + context->image->width > w)
+		return;
+	if (y + context->image->height > h)
 		return;
 
 	test_peer_begin_frame(client);
-	rect.x = 0;
-	rect.y = 0;
-	rect.width = context->icon_width;
-	rect.height = context->icon_height;
-
 	const BOOL RemoteFxCodec = freerdp_settings_get_bool(settings, FreeRDP_RemoteFxCodec);
 	if (RemoteFxCodec)
 	{
@@ -435,23 +426,31 @@ static void test_peer_draw_icon(freerdp_peer* client, UINT32 x, UINT32 y)
 
 	if (context->icon_x != UINT32_MAX)
 	{
+		const UINT32 colorFormat = PIXEL_FORMAT_RGB24;
+		const UINT32 bpp = FreeRDPGetBytesPerPixel(colorFormat);
 		s = test_peer_stream_init(context);
 
 		if (RemoteFxCodec)
+		{
+			rfx_context_set_pixel_format(context->rfx_context, colorFormat);
 			rfx_compose_message(context->rfx_context, s, &rect, 1, context->bg_data, rect.width,
-			                    rect.height, rect.width * 3);
+			                    rect.height, rect.width * bpp);
+		}
 		else
+		{
+			nsc_context_set_parameters(context->nsc_context, NSC_COLOR_FORMAT, colorFormat);
 			nsc_compose_message(context->nsc_context, s, context->bg_data, rect.width, rect.height,
-			                    rect.width * 3);
+			                    rect.width * bpp);
+		}
 
 		cmd.destLeft = context->icon_x;
 		cmd.destTop = context->icon_y;
-		cmd.destRight = context->icon_x + context->icon_width;
-		cmd.destBottom = context->icon_y + context->icon_height;
+		cmd.destRight = context->icon_x + rect.width;
+		cmd.destBottom = context->icon_y + rect.height;
 		cmd.bmp.bpp = 32;
 		cmd.bmp.flags = 0;
-		cmd.bmp.width = context->icon_width;
-		cmd.bmp.height = context->icon_height;
+		cmd.bmp.width = rect.width;
+		cmd.bmp.height = rect.height;
 		cmd.bmp.bitmapDataLength = (UINT32)Stream_GetPosition(s);
 		cmd.bmp.bitmapData = Stream_Buffer(s);
 		WINPR_ASSERT(update->SurfaceBits);
@@ -460,20 +459,31 @@ static void test_peer_draw_icon(freerdp_peer* client, UINT32 x, UINT32 y)
 
 	s = test_peer_stream_init(context);
 
-	if (RemoteFxCodec)
-		rfx_compose_message(context->rfx_context, s, &rect, 1, context->icon_data, rect.width,
-		                    rect.height, rect.width * 3);
-	else
-		nsc_compose_message(context->nsc_context, s, context->icon_data, rect.width, rect.height,
-		                    rect.width * 3);
+	{
+		const UINT32 colorFormat =
+		    context->image->bitsPerPixel > 24 ? PIXEL_FORMAT_BGRA32 : PIXEL_FORMAT_BGR24;
+
+		if (RemoteFxCodec)
+		{
+			rfx_context_set_pixel_format(context->rfx_context, colorFormat);
+			rfx_compose_message(context->rfx_context, s, &rect, 1, context->image->data, rect.width,
+			                    rect.height, context->image->scanline);
+		}
+		else
+		{
+			nsc_context_set_parameters(context->nsc_context, NSC_COLOR_FORMAT, colorFormat);
+			nsc_compose_message(context->nsc_context, s, context->image->data, rect.width,
+			                    rect.height, context->image->scanline);
+		}
+	}
 
 	cmd.destLeft = x;
 	cmd.destTop = y;
-	cmd.destRight = x + context->icon_width;
-	cmd.destBottom = y + context->icon_height;
+	cmd.destRight = x + rect.width;
+	cmd.destBottom = y + rect.height;
 	cmd.bmp.bpp = 32;
-	cmd.bmp.width = context->icon_width;
-	cmd.bmp.height = context->icon_height;
+	cmd.bmp.width = rect.width;
+	cmd.bmp.height = rect.height;
 	cmd.bmp.bitmapDataLength = (UINT32)Stream_GetPosition(s);
 	cmd.bmp.bitmapData = Stream_Buffer(s);
 	WINPR_ASSERT(update->SurfaceBits);
@@ -485,7 +495,8 @@ static void test_peer_draw_icon(freerdp_peer* client, UINT32 x, UINT32 y)
 
 static BOOL test_sleep_tsdiff(UINT32* old_sec, UINT32* old_usec, UINT32 new_sec, UINT32 new_usec)
 {
-	INT64 sec, usec;
+	INT64 sec = 0;
+	INT64 usec = 0;
 
 	WINPR_ASSERT(old_sec);
 	WINPR_ASSERT(old_usec);
@@ -526,13 +537,13 @@ static BOOL test_sleep_tsdiff(UINT32* old_sec, UINT32* old_usec, UINT32 new_sec,
 
 static BOOL tf_peer_dump_rfx(freerdp_peer* client)
 {
-	wStream* s;
-	UINT32 prev_seconds;
-	UINT32 prev_useconds;
-	rdpUpdate* update;
-	rdpPcap* pcap_rfx;
+	wStream* s = NULL;
+	UINT32 prev_seconds = 0;
+	UINT32 prev_useconds = 0;
+	rdpUpdate* update = NULL;
+	rdpPcap* pcap_rfx = NULL;
 	pcap_record record = { 0 };
-	struct server_info* info;
+	struct server_info* info = NULL;
 
 	WINPR_ASSERT(client);
 	WINPR_ASSERT(client->context);
@@ -585,11 +596,11 @@ static BOOL tf_peer_dump_rfx(freerdp_peer* client)
 
 static DWORD WINAPI tf_debug_channel_thread_func(LPVOID arg)
 {
-	void* fd;
-	wStream* s;
-	void* buffer;
+	void* fd = NULL;
+	wStream* s = NULL;
+	void* buffer = NULL;
 	DWORD BytesReturned = 0;
-	ULONG written;
+	ULONG written = 0;
 	testPeerContext* context = (testPeerContext*)arg;
 
 	WINPR_ASSERT(context);
@@ -608,7 +619,7 @@ static DWORD WINAPI tf_debug_channel_thread_func(LPVOID arg)
 
 	while (1)
 	{
-		DWORD status;
+		DWORD status = 0;
 		DWORD nCount = 0;
 		HANDLE handles[MAXIMUM_WAIT_OBJECTS] = { 0 };
 
@@ -652,8 +663,8 @@ fail:
 
 static BOOL tf_peer_post_connect(freerdp_peer* client)
 {
-	testPeerContext* context;
-	rdpSettings* settings;
+	testPeerContext* context = NULL;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(client);
 
@@ -763,9 +774,9 @@ static BOOL tf_peer_post_connect(freerdp_peer* client)
 
 static BOOL tf_peer_activate(freerdp_peer* client)
 {
-	testPeerContext* context;
-	struct server_info* info;
-	rdpSettings* settings;
+	testPeerContext* context = NULL;
+	struct server_info* info = NULL;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(client);
 
@@ -809,11 +820,11 @@ static BOOL tf_peer_synchronize_event(rdpInput* input, UINT32 flags)
 
 static BOOL tf_peer_keyboard_event(rdpInput* input, UINT16 flags, UINT8 code)
 {
-	freerdp_peer* client;
-	rdpUpdate* update;
-	rdpContext* context;
-	testPeerContext* tcontext;
-	rdpSettings* settings;
+	freerdp_peer* client = NULL;
+	rdpUpdate* update = NULL;
+	rdpContext* context = NULL;
+	testPeerContext* tcontext = NULL;
+	rdpSettings* settings = NULL;
 
 	WINPR_ASSERT(input);
 
@@ -867,7 +878,7 @@ static BOOL tf_peer_keyboard_event(rdpInput* input, UINT16 flags, UINT8 code)
 	{
 		if (tcontext->debug_channel)
 		{
-			ULONG written;
+			ULONG written = 0;
 			WTSVirtualChannelWrite(tcontext->debug_channel, (PCHAR) "test2", 5, &written);
 		}
 	}
@@ -930,14 +941,13 @@ static BOOL tf_peer_extended_mouse_event(rdpInput* input, UINT16 flags, UINT16 x
 
 static BOOL tf_peer_refresh_rect(rdpContext* context, BYTE count, const RECTANGLE_16* areas)
 {
-	BYTE i;
 	WINPR_UNUSED(context);
 	WINPR_ASSERT(context);
 	WINPR_ASSERT(areas || (count == 0));
 
 	WLog_DBG(TAG, "Client requested to refresh:");
 
-	for (i = 0; i < count; i++)
+	for (BYTE i = 0; i < count; i++)
 	{
 		WLog_DBG(TAG, "  (%" PRIu16 ", %" PRIu16 ") (%" PRIu16 ", %" PRIu16 ")", areas[i].left,
 		         areas[i].top, areas[i].right, areas[i].bottom);
@@ -970,10 +980,9 @@ static int hook_peer_write_pdu(rdpTransport* transport, wStream* s)
 	UINT64 ts = 0;
 	wStream* ls = NULL;
 	UINT64 last_ts = 0;
-	const struct server_info* info;
-	freerdp_peer* client;
-	CONNECTION_STATE state;
-	testPeerContext* peerCtx;
+	const struct server_info* info = NULL;
+	freerdp_peer* client = NULL;
+	testPeerContext* peerCtx = NULL;
 	size_t offset = 0;
 	UINT32 flags = 0;
 	rdpContext* context = transport_get_context(transport);
@@ -999,7 +1008,7 @@ static int hook_peer_write_pdu(rdpTransport* transport, wStream* s)
 	 * configuration as the one that recorded the session!
 	 */
 	WINPR_ASSERT(info);
-	state = freerdp_get_state(context);
+	CONNECTION_STATE state = freerdp_get_state(context);
 	if (state < CONNECTION_STATE_NEGO)
 		return peerCtx->io.WritePdu(transport, s);
 
@@ -1009,7 +1018,7 @@ static int hook_peer_write_pdu(rdpTransport* transport, wStream* s)
 
 	while (stream_dump_get(context, &flags, ls, &offset, &ts) > 0)
 	{
-		int rc;
+		int rc = 0;
 		/* Skip messages from client. */
 		if (flags & STREAM_MSG_SRV_TX)
 		{
@@ -1033,16 +1042,16 @@ fail:
 
 static DWORD WINAPI test_peer_mainloop(LPVOID arg)
 {
-	BOOL rc;
+	BOOL rc = 0;
 	DWORD error = CHANNEL_RC_OK;
 	HANDLE handles[MAXIMUM_WAIT_OBJECTS] = { 0 };
 	DWORD count = 0;
 	DWORD status = 0;
 	testPeerContext* context = NULL;
-	struct server_info* info;
-	rdpSettings* settings;
-	rdpInput* input;
-	rdpUpdate* update;
+	struct server_info* info = NULL;
+	rdpSettings* settings = NULL;
+	rdpInput* input = NULL;
+	rdpUpdate* update = NULL;
 	freerdp_peer* client = (freerdp_peer*)arg;
 
 	WINPR_ASSERT(client);
@@ -1160,7 +1169,9 @@ static DWORD WINAPI test_peer_mainloop(LPVOID arg)
 
 			count += tmp;
 		}
-		handles[count++] = WTSVirtualChannelManagerGetEventHandle(context->vcm);
+
+		HANDLE channelHandle = WTSVirtualChannelManagerGetEventHandle(context->vcm);
+		handles[count++] = channelHandle;
 		status = WaitForMultipleObjects(count, handles, FALSE, INFINITE);
 
 		if (status == WAIT_FAILED)
@@ -1173,6 +1184,9 @@ static DWORD WINAPI test_peer_mainloop(LPVOID arg)
 		if (client->CheckFileDescriptor(client) != TRUE)
 			break;
 
+		if (WaitForSingleObject(channelHandle, 0) != WAIT_OBJECT_0)
+			continue;
+
 		if (WTSVirtualChannelManagerCheckFileDescriptor(context->vcm) != TRUE)
 			break;
 
@@ -1229,8 +1243,8 @@ fail:
 
 static BOOL test_peer_accepted(freerdp_listener* instance, freerdp_peer* client)
 {
-	HANDLE hThread;
-	struct server_info* info;
+	HANDLE hThread = NULL;
+	struct server_info* info = NULL;
 
 	WINPR_UNUSED(instance);
 
