@@ -26,7 +26,6 @@
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <string.h>
 #include <ctype.h>
 
 #include <winpr/assert.h>
@@ -166,7 +165,7 @@ static void kerberos_ContextFree(KRB_CONTEXT* ctx, BOOL allocated)
 
 static KRB_CONTEXT* kerberos_ContextNew(void)
 {
-	KRB_CONTEXT* context;
+	KRB_CONTEXT* context = NULL;
 
 	context = (KRB_CONTEXT*)calloc(1, sizeof(KRB_CONTEXT));
 	if (!context)
@@ -395,7 +394,7 @@ static SECURITY_STATUS SEC_ENTRY kerberos_AcquireCredentialsHandleW(
     void* pAuthData, SEC_GET_KEY_FN pGetKeyFn, void* pvGetKeyArgument, PCredHandle phCredential,
     PTimeStamp ptsExpiry)
 {
-	SECURITY_STATUS status;
+	SECURITY_STATUS status = 0;
 	char* principal = NULL;
 	char* package = NULL;
 
@@ -427,8 +426,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_AcquireCredentialsHandleW(
 static SECURITY_STATUS SEC_ENTRY kerberos_FreeCredentialsHandle(PCredHandle phCredential)
 {
 #ifdef WITH_KRB5
-	KRB_CREDENTIALS* credentials;
-	krb5_context ctx;
+	KRB_CREDENTIALS* credentials = NULL;
+	krb5_context ctx = NULL;
 
 	credentials = sspi_SecureHandleGetLowerPointer(phCredential);
 	if (!credentials)
@@ -489,10 +488,10 @@ static SECURITY_STATUS SEC_ENTRY kerberos_QueryCredentialsAttributesA(PCredHandl
 static BOOL kerberos_mk_tgt_token(SecBuffer* buf, int msg_type, char* sname, char* host,
                                   const krb5_data* ticket)
 {
-	WinPrAsn1Encoder* enc;
+	WinPrAsn1Encoder* enc = NULL;
 	WinPrAsn1_MemoryChunk data;
 	wStream s;
-	size_t len;
+	size_t len = 0;
 	sspi_gss_data token;
 	BOOL ret = FALSE;
 
@@ -574,11 +573,12 @@ cleanup:
 
 static BOOL kerberos_rd_tgt_token(const sspi_gss_data* token, char** target, krb5_data* ticket)
 {
-	WinPrAsn1Decoder dec, dec2;
-	BOOL error;
-	WinPrAsn1_tagId tag;
-	WinPrAsn1_INTEGER val;
-	size_t len;
+	WinPrAsn1Decoder dec;
+	WinPrAsn1Decoder dec2;
+	BOOL error = 0;
+	WinPrAsn1_tagId tag = 0;
+	WinPrAsn1_INTEGER val = 0;
+	size_t len = 0;
 	wStream s;
 	char* buf = NULL;
 	char* str = NULL;
@@ -678,6 +678,8 @@ static BOOL kerberos_rd_tgt_token(const sspi_gss_data* token, char** target, krb
 
 fail:
 	free(buf);
+	if (target)
+		*target = NULL;
 	return FALSE;
 }
 
@@ -731,8 +733,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_InitializeSecurityContextA(
     PCtxtHandle phNewContext, PSecBufferDesc pOutput, ULONG* pfContextAttr, PTimeStamp ptsExpiry)
 {
 #ifdef WITH_KRB5
-	KRB_CREDENTIALS* credentials;
-	KRB_CONTEXT* context;
+	KRB_CREDENTIALS* credentials = NULL;
+	KRB_CONTEXT* context = NULL;
 	KRB_CONTEXT new_context = { 0 };
 	PSecBuffer input_buffer = NULL;
 	PSecBuffer output_buffer = NULL;
@@ -880,8 +882,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_InitializeSecurityContextA(
 			/* Write the checksum (delegation not implemented) */
 			cksum.data = cksum_contents;
 			cksum.length = sizeof(cksum_contents);
-			Data_Write_UINT32(cksum.data, 16);
-			Data_Write_UINT32((cksum.data + 20), context->flags);
+			Data_Write_UINT32(cksum_contents, 16);
+			Data_Write_UINT32((cksum_contents + 20), context->flags);
 
 			if (bindings_buffer)
 			{
@@ -975,7 +977,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_InitializeSecurityContextA(
 
 			context->state = KERBEROS_STATE_FINAL;
 
-			output_buffer->cbBuffer = 0;
+			if (output_buffer)
+				output_buffer->cbBuffer = 0;
 			status = SEC_E_OK;
 
 			break;
@@ -1037,7 +1040,7 @@ static SECURITY_STATUS SEC_ENTRY kerberos_InitializeSecurityContextW(
     ULONG Reserved1, ULONG TargetDataRep, PSecBufferDesc pInput, ULONG Reserved2,
     PCtxtHandle phNewContext, PSecBufferDesc pOutput, ULONG* pfContextAttr, PTimeStamp ptsExpiry)
 {
-	SECURITY_STATUS status;
+	SECURITY_STATUS status = 0;
 	char* target_name = NULL;
 
 	if (pszTargetName)
@@ -1063,22 +1066,22 @@ static SECURITY_STATUS SEC_ENTRY kerberos_AcceptSecurityContext(
     PTimeStamp ptsExpity)
 {
 #ifdef WITH_KRB5
-	KRB_CREDENTIALS* credentials;
-	KRB_CONTEXT* context;
+	KRB_CREDENTIALS* credentials = NULL;
+	KRB_CONTEXT* context = NULL;
 	KRB_CONTEXT new_context = { 0 };
 	PSecBuffer input_buffer = NULL;
 	PSecBuffer output_buffer = NULL;
 	WinPrAsn1_OID oid = { 0 };
-	uint16_t tok_id;
+	uint16_t tok_id = 0;
 	krb5_data input_token = { 0 };
 	krb5_data output_token = { 0 };
 	SECURITY_STATUS status = SEC_E_INTERNAL_ERROR;
 	krb5_flags ap_flags = 0;
-	krb5glue_authenticator authenticator;
+	krb5glue_authenticator authenticator = NULL;
 	char* target = NULL;
 	char* sname = NULL;
 	char* realm = NULL;
-	krb5_kt_cursor cur;
+	krb5_kt_cursor cur = { 0 };
 	krb5_keytab_entry entry = { 0 };
 	krb5_principal principal = NULL;
 	krb5_creds creds = { 0 };
@@ -1224,7 +1227,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_AcceptSecurityContext(
 		}
 		else
 		{
-			output_buffer->cbBuffer = 0;
+			if (output_buffer)
+				output_buffer->cbBuffer = 0;
 		}
 
 		*pfContextAttr = context->flags & 0x1F;
@@ -1331,8 +1335,10 @@ static SECURITY_STATUS SEC_ENTRY kerberos_QueryContextAttributesA(PCtxtHandle ph
 
 	if (ulAttribute == SECPKG_ATTR_SIZES)
 	{
-		UINT header, pad, trailer;
-		krb5glue_key key;
+		UINT header = 0;
+		UINT pad = 0;
+		UINT trailer = 0;
+		krb5glue_key key = NULL;
 		KRB_CONTEXT* context = get_context(phContext);
 		SecPkgContext_Sizes* ContextSizes = (SecPkgContext_Sizes*)pBuffer;
 
@@ -1414,7 +1420,7 @@ static SECURITY_STATUS SEC_ENTRY kerberos_SetCredentialsAttributesX(PCredHandle
                                                                     BOOL unicode)
 {
 #ifdef WITH_KRB5
-	KRB_CREDENTIALS* credentials;
+	KRB_CREDENTIALS* credentials = NULL;
 
 	if (!phCredential)
 		return SEC_E_INVALID_HANDLE;
@@ -1484,11 +1490,12 @@ static SECURITY_STATUS SEC_ENTRY kerberos_EncryptMessage(PCtxtHandle phContext,
 {
 #ifdef WITH_KRB5
 	KRB_CONTEXT* context = get_context(phContext);
-	PSecBuffer sig_buffer, data_buffer;
-	BYTE* header;
+	PSecBuffer sig_buffer = NULL;
+	PSecBuffer data_buffer = NULL;
+	BYTE* header = NULL;
 	BYTE flags = 0;
-	krb5glue_key key;
-	krb5_keyusage usage;
+	krb5glue_key key = NULL;
+	krb5_keyusage usage = 0;
 	krb5_crypto_iov encrypt_iov[] = { { KRB5_CRYPTO_TYPE_HEADER, { 0 } },
 		                              { KRB5_CRYPTO_TYPE_DATA, { 0 } },
 		                              { KRB5_CRYPTO_TYPE_DATA, { 0 } },
@@ -1536,9 +1543,9 @@ static SECURITY_STATUS SEC_ENTRY kerberos_EncryptMessage(PCtxtHandle phContext,
 	/* Set up the iov array in sig_buffer */
 	header = sig_buffer->pvBuffer;
 	encrypt_iov[2].data.data = header + 16;
-	encrypt_iov[3].data.data = encrypt_iov[2].data.data + encrypt_iov[2].data.length;
-	encrypt_iov[4].data.data = encrypt_iov[3].data.data + encrypt_iov[3].data.length;
-	encrypt_iov[0].data.data = encrypt_iov[4].data.data + encrypt_iov[4].data.length;
+	encrypt_iov[3].data.data = (BYTE*)encrypt_iov[2].data.data + encrypt_iov[2].data.length;
+	encrypt_iov[4].data.data = (BYTE*)encrypt_iov[3].data.data + encrypt_iov[3].data.length;
+	encrypt_iov[0].data.data = (BYTE*)encrypt_iov[4].data.data + encrypt_iov[4].data.length;
 	encrypt_iov[1].data.data = data_buffer->pvBuffer;
 
 	/* Write the GSS header with 0 in RRC */
@@ -1570,15 +1577,16 @@ static SECURITY_STATUS SEC_ENTRY kerberos_DecryptMessage(PCtxtHandle phContext,
 {
 #ifdef WITH_KRB5
 	KRB_CONTEXT* context = get_context(phContext);
-	PSecBuffer sig_buffer, data_buffer;
-	krb5glue_key key;
-	krb5_keyusage usage;
-	char* header;
-	uint16_t tok_id;
-	BYTE flags;
-	uint16_t ec;
-	uint16_t rrc;
-	uint64_t seq_no;
+	PSecBuffer sig_buffer = NULL;
+	PSecBuffer data_buffer = NULL;
+	krb5glue_key key = NULL;
+	krb5_keyusage usage = 0;
+	char* header = NULL;
+	uint16_t tok_id = 0;
+	BYTE flags = 0;
+	uint16_t ec = 0;
+	uint16_t rrc = 0;
+	uint64_t seq_no = 0;
 	krb5_crypto_iov iov[] = { { KRB5_CRYPTO_TYPE_HEADER, { 0 } },
 		                      { KRB5_CRYPTO_TYPE_DATA, { 0 } },
 		                      { KRB5_CRYPTO_TYPE_DATA, { 0 } },
@@ -1644,8 +1652,8 @@ static SECURITY_STATUS SEC_ENTRY kerberos_DecryptMessage(PCtxtHandle phContext,
 	iov[0].data.data = header + 16 + rrc + ec;
 	iov[1].data.data = data_buffer->pvBuffer;
 	iov[2].data.data = header + 16 + ec;
-	iov[3].data.data = iov[2].data.data + iov[2].data.length;
-	iov[4].data.data = iov[3].data.data + iov[3].data.length;
+	iov[3].data.data = (BYTE*)iov[2].data.data + iov[2].data.length;
+	iov[4].data.data = (BYTE*)iov[3].data.data + iov[3].data.length;
 
 	if (krb_log_exec(krb5glue_decrypt_iov, context->ctx, key, usage, iov, ARRAYSIZE(iov)))
 		return SEC_E_INTERNAL_ERROR;
@@ -1669,10 +1677,11 @@ static SECURITY_STATUS SEC_ENTRY kerberos_MakeSignature(PCtxtHandle phContext, U
 {
 #ifdef WITH_KRB5
 	KRB_CONTEXT* context = get_context(phContext);
-	PSecBuffer sig_buffer, data_buffer;
-	krb5glue_key key;
-	krb5_keyusage usage;
-	char* header;
+	PSecBuffer sig_buffer = NULL;
+	PSecBuffer data_buffer = NULL;
+	krb5glue_key key = NULL;
+	krb5_keyusage usage = 0;
+	char* header = NULL;
 	BYTE flags = 0;
 	krb5_crypto_iov iov[] = { { KRB5_CRYPTO_TYPE_DATA, { 0 } },
 		                      { KRB5_CRYPTO_TYPE_DATA, { 0 } },
@@ -1737,14 +1746,15 @@ static SECURITY_STATUS SEC_ENTRY kerberos_VerifySignature(PCtxtHandle phContext,
                                                           ULONG MessageSeqNo, ULONG* pfQOP)
 {
 #ifdef WITH_KRB5
-	PSecBuffer sig_buffer, data_buffer;
-	krb5glue_key key;
-	krb5_keyusage usage;
-	char* header;
-	BYTE flags;
-	uint16_t tok_id;
-	uint64_t seq_no;
-	krb5_boolean is_valid;
+	PSecBuffer sig_buffer = NULL;
+	PSecBuffer data_buffer = NULL;
+	krb5glue_key key = NULL;
+	krb5_keyusage usage = 0;
+	char* header = NULL;
+	BYTE flags = 0;
+	uint16_t tok_id = 0;
+	uint64_t seq_no = 0;
+	krb5_boolean is_valid = 0;
 	krb5_crypto_iov iov[] = { { KRB5_CRYPTO_TYPE_DATA, { 0 } },
 		                      { KRB5_CRYPTO_TYPE_DATA, { 0 } },
 		                      { KRB5_CRYPTO_TYPE_CHECKSUM, { 0 } } };
