@@ -25,7 +25,6 @@
 #include <winpr/assert.h>
 #include <winpr/sspi.h>
 #include <winpr/tchar.h>
-#include <winpr/assert.h>
 #include <winpr/registry.h>
 #include <winpr/build-config.h>
 #include <winpr/asn1.h>
@@ -235,7 +234,8 @@ static PSecHandle negotiate_FindCredential(MechCred* creds, const Mech* mech)
 
 static BOOL negotiate_get_dword(HKEY hKey, const char* subkey, DWORD* pdwValue)
 {
-	DWORD dwValue = 0, dwType = 0;
+	DWORD dwValue = 0;
+	DWORD dwType = 0;
 	DWORD dwSize = sizeof(dwValue);
 	LONG rc = RegQueryValueExA(hKey, subkey, NULL, &dwType, (BYTE*)&dwValue, &dwSize);
 
@@ -293,7 +293,7 @@ static BOOL negotiate_get_config_from_auth_package_list(void* pAuthData, BOOL* k
 static BOOL negotiate_get_config(void* pAuthData, BOOL* kerberos, BOOL* ntlm)
 {
 	HKEY hKey = NULL;
-	LONG rc;
+	LONG rc = 0;
 
 	WINPR_ASSERT(kerberos);
 	WINPR_ASSERT(ntlm);
@@ -313,7 +313,7 @@ static BOOL negotiate_get_config(void* pAuthData, BOOL* kerberos, BOOL* ntlm)
 	rc = RegOpenKeyExA(HKEY_LOCAL_MACHINE, NEGO_REG_KEY, 0, KEY_READ | KEY_WOW64_64KEY, &hKey);
 	if (rc == ERROR_SUCCESS)
 	{
-		DWORD dwValue;
+		DWORD dwValue = 0;
 
 		if (negotiate_get_dword(hKey, "kerberos", &dwValue))
 			*kerberos = (dwValue != 0) ? TRUE : FALSE;
@@ -340,7 +340,7 @@ static BOOL negotiate_write_neg_token(PSecBuffer output_buffer, NegToken* token)
 	WinPrAsn1_OctetString mechToken = { token->mechToken.cbBuffer, token->mechToken.pvBuffer };
 	WinPrAsn1_OctetString mechListMic = { token->mic.cbBuffer, token->mic.pvBuffer };
 	wStream s;
-	size_t len;
+	size_t len = 0;
 
 	enc = WinPrAsn1Encoder_New(WINPR_ASN1_DER);
 	if (!enc)
@@ -435,11 +435,11 @@ static BOOL negotiate_read_neg_token(PSecBuffer input, NegToken* token)
 	WinPrAsn1Decoder dec;
 	WinPrAsn1Decoder dec2;
 	WinPrAsn1_OID oid;
-	WinPrAsn1_tagId contextual;
-	WinPrAsn1_tag tag;
-	size_t len;
+	WinPrAsn1_tagId contextual = 0;
+	WinPrAsn1_tag tag = 0;
+	size_t len = 0;
 	WinPrAsn1_OctetString octet_string;
-	BOOL err;
+	BOOL err = 0;
 
 	WINPR_ASSERT(input);
 	WINPR_ASSERT(token);
@@ -497,7 +497,7 @@ static BOOL negotiate_read_neg_token(PSecBuffer input, NegToken* token)
 				else
 				{
 					/* negState [0] ENUMERATED */
-					WinPrAsn1_ENUMERATED rd;
+					WinPrAsn1_ENUMERATED rd = 0;
 					if (!WinPrAsn1DecReadEnumerated(&dec2, &rd))
 						return FALSE;
 					token->negState = rd;
@@ -553,7 +553,7 @@ static SECURITY_STATUS negotiate_mic_exchange(NEGOTIATE_CONTEXT* context, NegTok
 {
 	SecBuffer mic_buffers[2] = { 0 };
 	SecBufferDesc mic_buffer_desc = { SECBUFFER_VERSION, 2, mic_buffers };
-	SECURITY_STATUS status;
+	SECURITY_STATUS status = 0;
 
 	WINPR_ASSERT(context);
 	WINPR_ASSERT(input_token);
@@ -583,10 +583,12 @@ static SECURITY_STATUS negotiate_mic_exchange(NEGOTIATE_CONTEXT* context, NegTok
 	{
 		/* Store the mic token after the mech token in the output buffer */
 		output_token->mic.BufferType = SECBUFFER_TOKEN;
-		output_token->mic.cbBuffer = output_buffer->cbBuffer - output_token->mechToken.cbBuffer;
-		output_token->mic.pvBuffer =
-		    (BYTE*)output_buffer->pvBuffer + output_token->mechToken.cbBuffer;
-
+		if (output_buffer)
+		{
+			output_token->mic.cbBuffer = output_buffer->cbBuffer - output_token->mechToken.cbBuffer;
+			output_token->mic.pvBuffer =
+			    (BYTE*)output_buffer->pvBuffer + output_token->mechToken.cbBuffer;
+		}
 		mic_buffers[1] = output_token->mic;
 
 		status = table->MakeSignature(&context->sub_context, 0, &mic_buffer_desc, 0);
@@ -613,7 +615,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_InitializeSecurityContextW(
 {
 	NEGOTIATE_CONTEXT* context = NULL;
 	NEGOTIATE_CONTEXT init_context = { 0 };
-	MechCred* creds;
+	MechCred* creds = NULL;
 	PCtxtHandle sub_context = NULL;
 	PCredHandle sub_cred = NULL;
 	NegToken input_token = empty_neg_token;
@@ -628,7 +630,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_InitializeSecurityContextW(
 	SECURITY_STATUS sub_status = SEC_E_INTERNAL_ERROR;
 	WinPrAsn1Encoder* enc = NULL;
 	wStream s;
-	const Mech* mech;
+	const Mech* mech = NULL;
 
 	if (!phCredential || !SecIsValidHandle(phCredential))
 		return SEC_E_NO_CREDENTIALS;
@@ -849,7 +851,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_InitializeSecurityContextW(
 			if (context->mic || input_token.negState != ACCEPT_COMPLETED)
 				return SEC_E_INVALID_TOKEN;
 
-			output_buffer->cbBuffer = 0;
+			if (output_buffer)
+				output_buffer->cbBuffer = 0;
 			return SEC_E_OK;
 		}
 
@@ -864,7 +867,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_InitializeSecurityContextW(
 
 	if (input_token.negState == ACCEPT_COMPLETED)
 	{
-		output_buffer->cbBuffer = 0;
+		if (output_buffer)
+			output_buffer->cbBuffer = 0;
 		return SEC_E_OK;
 	}
 
@@ -886,7 +890,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_InitializeSecurityContextA(
     ULONG Reserved1, ULONG TargetDataRep, PSecBufferDesc pInput, ULONG Reserved2,
     PCtxtHandle phNewContext, PSecBufferDesc pOutput, PULONG pfContextAttr, PTimeStamp ptsExpiry)
 {
-	SECURITY_STATUS status;
+	SECURITY_STATUS status = 0;
 	SEC_WCHAR* pszTargetNameW = NULL;
 
 	if (pszTargetName)
@@ -907,7 +911,7 @@ static const Mech* guessMech(PSecBuffer input_buffer, BOOL* spNego, WinPrAsn1_OI
 {
 	WinPrAsn1Decoder decoder;
 	WinPrAsn1Decoder appDecoder;
-	WinPrAsn1_tagId tag;
+	WinPrAsn1_tagId tag = 0;
 
 	*spNego = FALSE;
 
@@ -944,7 +948,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcceptSecurityContext(
 {
 	NEGOTIATE_CONTEXT* context = NULL;
 	NEGOTIATE_CONTEXT init_context = { 0 };
-	MechCred* creds;
+	MechCred* creds = NULL;
 	PCredHandle sub_cred = NULL;
 	NegToken input_token = empty_neg_token;
 	NegToken output_token = empty_neg_token;
@@ -953,8 +957,9 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcceptSecurityContext(
 	SecBufferDesc mech_input = { SECBUFFER_VERSION, 1, &input_token.mechToken };
 	SecBufferDesc mech_output = { SECBUFFER_VERSION, 1, &output_token.mechToken };
 	SECURITY_STATUS status = SEC_E_INTERNAL_ERROR;
-	WinPrAsn1Decoder dec, dec2;
-	WinPrAsn1_tagId tag;
+	WinPrAsn1Decoder dec;
+	WinPrAsn1Decoder dec2;
+	WinPrAsn1_tagId tag = 0;
 	WinPrAsn1_OID oid = { 0 };
 	const Mech* first_mech = NULL;
 
@@ -1015,7 +1020,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcceptSecurityContext(
 
 				if (init_context.mech)
 				{
-					output_token.mechToken = *output_buffer;
+					if (output_buffer)
+						output_token.mechToken = *output_buffer;
 					WLog_DBG(TAG, "Requested mechanism: %s",
 					         negotiate_mech_name(init_context.mech->oid));
 				}
@@ -1155,7 +1161,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcceptSecurityContext(
 
 	if (input_token.negState == ACCEPT_COMPLETED)
 	{
-		output_buffer->cbBuffer = 0;
+		if (output_buffer)
+			output_buffer->cbBuffer = 0;
 		return SEC_E_OK;
 	}
 
@@ -1173,7 +1180,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcceptSecurityContext(
 static SECURITY_STATUS SEC_ENTRY negotiate_CompleteAuthToken(PCtxtHandle phContext,
                                                              PSecBufferDesc pToken)
 {
-	NEGOTIATE_CONTEXT* context;
+	NEGOTIATE_CONTEXT* context = NULL;
 	SECURITY_STATUS status = SEC_E_OK;
 	context = (NEGOTIATE_CONTEXT*)sspi_SecureHandleGetLowerPointer(phContext);
 
@@ -1191,10 +1198,10 @@ static SECURITY_STATUS SEC_ENTRY negotiate_CompleteAuthToken(PCtxtHandle phConte
 
 static SECURITY_STATUS SEC_ENTRY negotiate_DeleteSecurityContext(PCtxtHandle phContext)
 {
-	NEGOTIATE_CONTEXT* context;
+	NEGOTIATE_CONTEXT* context = NULL;
 	SECURITY_STATUS status = SEC_E_OK;
 	context = (NEGOTIATE_CONTEXT*)sspi_SecureHandleGetLowerPointer(phContext);
-	const SecPkg* pkg;
+	const SecPkg* pkg = NULL;
 
 	if (!context)
 		return SEC_E_INVALID_HANDLE;
@@ -1299,9 +1306,9 @@ static SECURITY_STATUS SEC_ENTRY negotiate_SetCredentialsAttributesW(PCredHandle
                                                                      ULONG ulAttribute,
                                                                      void* pBuffer, ULONG cbBuffer)
 {
-	MechCred* creds;
+	MechCred* creds = NULL;
 	BOOL success = FALSE;
-	SECURITY_STATUS secStatus;
+	SECURITY_STATUS secStatus = 0;
 
 	creds = sspi_SecureHandleGetLowerPointer(phCredential);
 
@@ -1333,9 +1340,9 @@ static SECURITY_STATUS SEC_ENTRY negotiate_SetCredentialsAttributesA(PCredHandle
                                                                      ULONG ulAttribute,
                                                                      void* pBuffer, ULONG cbBuffer)
 {
-	MechCred* creds;
+	MechCred* creds = NULL;
 	BOOL success = FALSE;
-	SECURITY_STATUS secStatus;
+	SECURITY_STATUS secStatus = 0;
 
 	creds = sspi_SecureHandleGetLowerPointer(phCredential);
 
@@ -1371,7 +1378,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcquireCredentialsHandleW(
     void* pAuthData, SEC_GET_KEY_FN pGetKeyFn, void* pvGetKeyArgument, PCredHandle phCredential,
     PTimeStamp ptsExpiry)
 {
-	BOOL kerberos, ntlm;
+	BOOL kerberos = 0;
+	BOOL ntlm = 0;
 
 	if (!negotiate_get_config(pAuthData, &kerberos, &ntlm))
 		return SEC_E_INTERNAL_ERROR;
@@ -1412,7 +1420,8 @@ static SECURITY_STATUS SEC_ENTRY negotiate_AcquireCredentialsHandleA(
     void* pAuthData, SEC_GET_KEY_FN pGetKeyFn, void* pvGetKeyArgument, PCredHandle phCredential,
     PTimeStamp ptsExpiry)
 {
-	BOOL kerberos, ntlm;
+	BOOL kerberos = 0;
+	BOOL ntlm = 0;
 
 	if (!negotiate_get_config(pAuthData, &kerberos, &ntlm))
 		return SEC_E_INTERNAL_ERROR;
@@ -1467,7 +1476,7 @@ static SECURITY_STATUS SEC_ENTRY negotiate_QueryCredentialsAttributesA(PCredHand
 
 static SECURITY_STATUS SEC_ENTRY negotiate_FreeCredentialsHandle(PCredHandle phCredential)
 {
-	MechCred* creds;
+	MechCred* creds = NULL;
 
 	creds = sspi_SecureHandleGetLowerPointer(phCredential);
 	if (!creds)
