@@ -57,21 +57,18 @@ int CommandLineParseArgumentsA(int argc, LPSTR* argv, COMMAND_LINE_ARGUMENT_A* o
                                void* context, COMMAND_LINE_PRE_FILTER_FN_A preFilter,
                                COMMAND_LINE_POST_FILTER_FN_A postFilter)
 {
-	int i, j;
-	int status;
-	int count;
-	size_t length;
-	BOOL notescaped;
-	const char* sigil;
-	size_t sigil_length;
-	char* keyword;
-	size_t keyword_length;
-	SSIZE_T keyword_index;
-	char* separator;
-	char* value;
-	int toggle;
-	status = 0;
-	notescaped = FALSE;
+	int status = 0;
+	int count = 0;
+	size_t length = 0;
+	BOOL notescaped = FALSE;
+	const char* sigil = NULL;
+	size_t sigil_length = 0;
+	char* keyword = NULL;
+	size_t keyword_length = 0;
+	SSIZE_T keyword_index = 0;
+	char* separator = NULL;
+	char* value = NULL;
+	int toggle = 0;
 
 	if (!argv)
 		return status;
@@ -86,7 +83,7 @@ int CommandLineParseArgumentsA(int argc, LPSTR* argv, COMMAND_LINE_ARGUMENT_A* o
 		return status;
 	}
 
-	for (i = 1; i < argc; i++)
+	for (int i = 1; i < argc; i++)
 	{
 		BOOL found = FALSE;
 		BOOL escaped = TRUE;
@@ -212,7 +209,7 @@ int CommandLineParseArgumentsA(int argc, LPSTR* argv, COMMAND_LINE_ARGUMENT_A* o
 			if (!escaped)
 				continue;
 
-			for (j = 0; options[j].Name != NULL; j++)
+			for (int j = 0; options[j].Name != NULL; j++)
 			{
 				COMMAND_LINE_ARGUMENT_A* cur = &options[j];
 				BOOL match = FALSE;
@@ -240,7 +237,7 @@ int CommandLineParseArgumentsA(int argc, LPSTR* argv, COMMAND_LINE_ARGUMENT_A* o
 
 				if ((flags & COMMAND_LINE_SEPARATOR_SPACE) && ((i + 1) < argc))
 				{
-					BOOL argument;
+					BOOL argument = 0;
 					int value_present = 1;
 
 					if (flags & COMMAND_LINE_SIGIL_DASH)
@@ -396,9 +393,7 @@ int CommandLineParseArgumentsW(int argc, LPWSTR* argv, COMMAND_LINE_ARGUMENT_W*
 
 int CommandLineClearArgumentsA(COMMAND_LINE_ARGUMENT_A* options)
 {
-	size_t i;
-
-	for (i = 0; options[i].Name != NULL; i++)
+	for (size_t i = 0; options[i].Name != NULL; i++)
 	{
 		options[i].Flags &= COMMAND_LINE_INPUT_FLAG_MASK;
 		options[i].Value = NULL;
@@ -409,9 +404,7 @@ int CommandLineClearArgumentsA(COMMAND_LINE_ARGUMENT_A* options)
 
 int CommandLineClearArgumentsW(COMMAND_LINE_ARGUMENT_W* options)
 {
-	int i;
-
-	for (i = 0; options[i].Name != NULL; i++)
+	for (int i = 0; options[i].Name != NULL; i++)
 	{
 		options[i].Flags &= COMMAND_LINE_INPUT_FLAG_MASK;
 		options[i].Value = NULL;
@@ -423,12 +416,10 @@ int CommandLineClearArgumentsW(COMMAND_LINE_ARGUMENT_W* options)
 const COMMAND_LINE_ARGUMENT_A* CommandLineFindArgumentA(const COMMAND_LINE_ARGUMENT_A* options,
                                                         LPCSTR Name)
 {
-	size_t i;
-
 	WINPR_ASSERT(options);
 	WINPR_ASSERT(Name);
 
-	for (i = 0; options[i].Name != NULL; i++)
+	for (size_t i = 0; options[i].Name != NULL; i++)
 	{
 		if (strcmp(options[i].Name, Name) == 0)
 			return &options[i];
@@ -446,12 +437,10 @@ const COMMAND_LINE_ARGUMENT_A* CommandLineFindArgumentA(const COMMAND_LINE_ARGUM
 const COMMAND_LINE_ARGUMENT_W* CommandLineFindArgumentW(const COMMAND_LINE_ARGUMENT_W* options,
                                                         LPCWSTR Name)
 {
-	size_t i;
-
 	WINPR_ASSERT(options);
 	WINPR_ASSERT(Name);
 
-	for (i = 0; options[i].Name != NULL; i++)
+	for (size_t i = 0; options[i].Name != NULL; i++)
 	{
 		if (_wcscmp(options[i].Name, Name) == 0)
 			return &options[i];
@@ -468,7 +457,7 @@ const COMMAND_LINE_ARGUMENT_W* CommandLineFindArgumentW(const COMMAND_LINE_ARGUM
 
 const COMMAND_LINE_ARGUMENT_A* CommandLineFindNextArgumentA(const COMMAND_LINE_ARGUMENT_A* argument)
 {
-	const COMMAND_LINE_ARGUMENT_A* nextArgument;
+	const COMMAND_LINE_ARGUMENT_A* nextArgument = NULL;
 
 	if (!argument || !argument->Name)
 		return NULL;
@@ -656,7 +645,6 @@ char** CommandLineParseCommaSeparatedValuesEx(const char* name, const char* list
 	char** p = NULL;
 	char* str = NULL;
 	size_t nArgs = 0;
-	size_t index = 0;
 	size_t prefix = 0;
 	size_t len = 0;
 	size_t namelen = 0;
@@ -672,7 +660,8 @@ char** CommandLineParseCommaSeparatedValuesEx(const char* name, const char* list
 	*count = 0;
 	if (list)
 	{
-		int start, end;
+		int start = 0;
+		int end = 0;
 		unquoted = copy = _strdup(list);
 		if (!copy)
 			goto fail;
@@ -749,7 +738,7 @@ char** CommandLineParseCommaSeparatedValuesEx(const char* name, const char* list
 		p[0] = namestr;
 	}
 
-	for (index = name ? 1 : 0; index < nArgs; index++)
+	for (size_t index = name ? 1 : 0; index < nArgs; index++)
 	{
 		char* ptr = str;
 		const int quote = is_quoted(*ptr);
@@ -794,7 +783,8 @@ fail:
 	free(copy);
 	if (!success)
 	{
-		*count = 0;
+		if (count)
+			*count = 0;
 		free(p);
 		return NULL;
 	}
@@ -813,10 +803,9 @@ char* CommandLineToCommaSeparatedValues(int argc, char* argv[])
 
 static const char* filtered(const char* arg, const char* filters[], size_t number)
 {
-	size_t x;
 	if (number == 0)
 		return arg;
-	for (x = 0; x < number; x++)
+	for (size_t x = 0; x < number; x++)
 	{
 		const char* filter = filters[x];
 		size_t len = strlen(filter);
@@ -829,22 +818,21 @@ static const char* filtered(const char* arg, const char* filters[], size_t numbe
 char* CommandLineToCommaSeparatedValuesEx(int argc, char* argv[], const char* filters[],
                                           size_t number)
 {
-	int x;
 	char* str = NULL;
 	size_t offset = 0;
 	size_t size = argc + 1;
 	if ((argc <= 0) || !argv)
 		return NULL;
 
-	for (x = 0; x < argc; x++)
+	for (int x = 0; x < argc; x++)
 		size += strlen(argv[x]);
 
 	str = calloc(size, sizeof(char));
 	if (!str)
 		return NULL;
-	for (x = 0; x < argc; x++)
+	for (int x = 0; x < argc; x++)
 	{
-		int rc;
+		int rc = 0;
 		const char* arg = filtered(argv[x], filters, number);
 		if (!arg)
 			continue;
